Coverage for /run/media/veganeco/water/status600.com/pypi/reptilian_climates/modules_series_2/ships/fields/gardens_pip/rich/_emoji_codes.py: 100%

1 EMOJI = {

2 "1st_place_medal": "🥇",

3 "2nd_place_medal": "🥈",

4 "3rd_place_medal": "🥉",

5 "ab_button_(blood_type)": "🆎",

6 "atm_sign": "🏧",

7 "a_button_(blood_type)": "🅰",

8 "afghanistan": "🇦🇫",

9 "albania": "🇦🇱",

10 "algeria": "🇩🇿",

11 "american_samoa": "🇦🇸",

12 "andorra": "🇦🇩",

13 "angola": "🇦🇴",

14 "anguilla": "🇦🇮",

15 "antarctica": "🇦🇶",

16 "antigua_&_barbuda": "🇦🇬",

17 "aquarius": "♒",

18 "argentina": "🇦🇷",

19 "aries": "♈",

20 "armenia": "🇦🇲",

21 "aruba": "🇦🇼",

22 "ascension_island": "🇦🇨",

23 "australia": "🇦🇺",

24 "austria": "🇦🇹",

25 "azerbaijan": "🇦🇿",

26 "back_arrow": "🔙",

27 "b_button_(blood_type)": "🅱",

28 "bahamas": "🇧🇸",

29 "bahrain": "🇧🇭",

30 "bangladesh": "🇧🇩",

31 "barbados": "🇧🇧",

32 "belarus": "🇧🇾",

33 "belgium": "🇧🇪",

34 "belize": "🇧🇿",

35 "benin": "🇧🇯",

36 "bermuda": "🇧🇲",

37 "bhutan": "🇧🇹",

38 "bolivia": "🇧🇴",

39 "bosnia_&_herzegovina": "🇧🇦",

40 "botswana": "🇧🇼",

41 "bouvet_island": "🇧🇻",

42 "brazil": "🇧🇷",

43 "british_indian_ocean_territory": "🇮🇴",

44 "british_virgin_islands": "🇻🇬",

45 "brunei": "🇧🇳",

46 "bulgaria": "🇧🇬",

47 "burkina_faso": "🇧🇫",

48 "burundi": "🇧🇮",

49 "cl_button": "🆑",

50 "cool_button": "🆒",

51 "cambodia": "🇰🇭",

52 "cameroon": "🇨🇲",

53 "canada": "🇨🇦",

54 "canary_islands": "🇮🇨",

55 "cancer": "♋",

56 "cape_verde": "🇨🇻",

57 "capricorn": "♑",

58 "caribbean_netherlands": "🇧🇶",

59 "cayman_islands": "🇰🇾",

60 "central_african_republic": "🇨🇫",

61 "ceuta_&_melilla": "🇪🇦",

62 "chad": "🇹🇩",

63 "chile": "🇨🇱",

64 "china": "🇨🇳",

65 "christmas_island": "🇨🇽",

66 "christmas_tree": "🎄",

67 "clipperton_island": "🇨🇵",

68 "cocos_(keeling)_islands": "🇨🇨",

69 "colombia": "🇨🇴",

70 "comoros": "🇰🇲",

71 "congo_-_brazzaville": "🇨🇬",

72 "congo_-_kinshasa": "🇨🇩",

73 "cook_islands": "🇨🇰",

74 "costa_rica": "🇨🇷",

75 "croatia": "🇭🇷",

76 "cuba": "🇨🇺",

77 "curaçao": "🇨🇼",

78 "cyprus": "🇨🇾",

79 "czechia": "🇨🇿",

80 "côte_d’ivoire": "🇨🇮",

81 "denmark": "🇩🇰",

82 "diego_garcia": "🇩🇬",

83 "djibouti": "🇩🇯",

84 "dominica": "🇩🇲",

85 "dominican_republic": "🇩🇴",

86 "end_arrow": "🔚",

87 "ecuador": "🇪🇨",

88 "egypt": "🇪🇬",

89 "el_salvador": "🇸🇻",

90 "england": "🏴\U000e0067\U000e0062\U000e0065\U000e006e\U000e0067\U000e007f",

91 "equatorial_guinea": "🇬🇶",

92 "eritrea": "🇪🇷",

93 "estonia": "🇪🇪",

94 "ethiopia": "🇪🇹",

95 "european_union": "🇪🇺",

96 "free_button": "🆓",

97 "falkland_islands": "🇫🇰",

98 "faroe_islands": "🇫🇴",

99 "fiji": "🇫🇯",

100 "finland": "🇫🇮",

101 "france": "🇫🇷",

102 "french_guiana": "🇬🇫",

103 "french_polynesia": "🇵🇫",

104 "french_southern_territories": "🇹🇫",

105 "gabon": "🇬🇦",

106 "gambia": "🇬🇲",

107 "gemini": "♊",

108 "georgia": "🇬🇪",

109 "germany": "🇩🇪",

110 "ghana": "🇬🇭",

111 "gibraltar": "🇬🇮",

112 "greece": "🇬🇷",

113 "greenland": "🇬🇱",

114 "grenada": "🇬🇩",

115 "guadeloupe": "🇬🇵",

116 "guam": "🇬🇺",

117 "guatemala": "🇬🇹",

118 "guernsey": "🇬🇬",

119 "guinea": "🇬🇳",

120 "guinea-bissau": "🇬🇼",

121 "guyana": "🇬🇾",

122 "haiti": "🇭🇹",

123 "heard_&_mcdonald_islands": "🇭🇲",

124 "honduras": "🇭🇳",

125 "hong_kong_sar_china": "🇭🇰",

126 "hungary": "🇭🇺",

127 "id_button": "🆔",

128 "iceland": "🇮🇸",

129 "india": "🇮🇳",

130 "indonesia": "🇮🇩",

131 "iran": "🇮🇷",

132 "iraq": "🇮🇶",

133 "ireland": "🇮🇪",

134 "isle_of_man": "🇮🇲",

135 "israel": "🇮🇱",

136 "italy": "🇮🇹",

137 "jamaica": "🇯🇲",

138 "japan": "🗾",

139 "japanese_acceptable_button": "🉑",

140 "japanese_application_button": "🈸",

141 "japanese_bargain_button": "🉐",

142 "japanese_castle": "🏯",

143 "japanese_congratulations_button": "㊗",

144 "japanese_discount_button": "🈹",

145 "japanese_dolls": "🎎",

146 "japanese_free_of_charge_button": "🈚",

147 "japanese_here_button": "🈁",

148 "japanese_monthly_amount_button": "🈷",

149 "japanese_no_vacancy_button": "🈵",

150 "japanese_not_free_of_charge_button": "🈶",

151 "japanese_open_for_business_button": "🈺",

152 "japanese_passing_grade_button": "🈴",

153 "japanese_post_office": "🏣",

154 "japanese_prohibited_button": "🈲",

155 "japanese_reserved_button": "🈯",

156 "japanese_secret_button": "㊙",

157 "japanese_service_charge_button": "🈂",

158 "japanese_symbol_for_beginner": "🔰",

159 "japanese_vacancy_button": "🈳",

160 "jersey": "🇯🇪",

161 "jordan": "🇯🇴",

162 "kazakhstan": "🇰🇿",

163 "kenya": "🇰🇪",

164 "kiribati": "🇰🇮",

165 "kosovo": "🇽🇰",

166 "kuwait": "🇰🇼",

167 "kyrgyzstan": "🇰🇬",

168 "laos": "🇱🇦",

169 "latvia": "🇱🇻",

170 "lebanon": "🇱🇧",

171 "leo": "♌",

172 "lesotho": "🇱🇸",

173 "liberia": "🇱🇷",

174 "libra": "♎",

175 "libya": "🇱🇾",

176 "liechtenstein": "🇱🇮",

177 "lithuania": "🇱🇹",

178 "luxembourg": "🇱🇺",

179 "macau_sar_china": "🇲🇴",

180 "macedonia": "🇲🇰",

181 "madagascar": "🇲🇬",

182 "malawi": "🇲🇼",

183 "malaysia": "🇲🇾",

184 "maldives": "🇲🇻",

185 "mali": "🇲🇱",

186 "malta": "🇲🇹",

187 "marshall_islands": "🇲🇭",

188 "martinique": "🇲🇶",

189 "mauritania": "🇲🇷",

190 "mauritius": "🇲🇺",

191 "mayotte": "🇾🇹",

192 "mexico": "🇲🇽",

193 "micronesia": "🇫🇲",

194 "moldova": "🇲🇩",

195 "monaco": "🇲🇨",

196 "mongolia": "🇲🇳",

197 "montenegro": "🇲🇪",

198 "montserrat": "🇲🇸",

199 "morocco": "🇲🇦",

200 "mozambique": "🇲🇿",

201 "mrs._claus": "🤶",

202 "mrs._claus_dark_skin_tone": "🤶🏿",

203 "mrs._claus_light_skin_tone": "🤶🏻",

204 "mrs._claus_medium-dark_skin_tone": "🤶🏾",

205 "mrs._claus_medium-light_skin_tone": "🤶🏼",

206 "mrs._claus_medium_skin_tone": "🤶🏽",

207 "myanmar_(burma)": "🇲🇲",

208 "new_button": "🆕",

209 "ng_button": "🆖",

210 "namibia": "🇳🇦",

211 "nauru": "🇳🇷",

212 "nepal": "🇳🇵",

213 "netherlands": "🇳🇱",

214 "new_caledonia": "🇳🇨",

215 "new_zealand": "🇳🇿",

216 "nicaragua": "🇳🇮",

217 "niger": "🇳🇪",

218 "nigeria": "🇳🇬",

219 "niue": "🇳🇺",

220 "norfolk_island": "🇳🇫",

221 "north_korea": "🇰🇵",

222 "northern_mariana_islands": "🇲🇵",

223 "norway": "🇳🇴",

224 "ok_button": "🆗",

225 "ok_hand": "👌",

226 "ok_hand_dark_skin_tone": "👌🏿",

227 "ok_hand_light_skin_tone": "👌🏻",

228 "ok_hand_medium-dark_skin_tone": "👌🏾",

229 "ok_hand_medium-light_skin_tone": "👌🏼",

230 "ok_hand_medium_skin_tone": "👌🏽",

231 "on!_arrow": "🔛",

232 "o_button_(blood_type)": "🅾",

233 "oman": "🇴🇲",

234 "ophiuchus": "⛎",

235 "p_button": "🅿",

236 "pakistan": "🇵🇰",

237 "palau": "🇵🇼",

238 "palestinian_territories": "🇵🇸",

239 "panama": "🇵🇦",

240 "papua_new_guinea": "🇵🇬",

241 "paraguay": "🇵🇾",

242 "peru": "🇵🇪",

243 "philippines": "🇵🇭",

244 "pisces": "♓",

245 "pitcairn_islands": "🇵🇳",

246 "poland": "🇵🇱",

247 "portugal": "🇵🇹",

248 "puerto_rico": "🇵🇷",

249 "qatar": "🇶🇦",

250 "romania": "🇷🇴",

251 "russia": "🇷🇺",

252 "rwanda": "🇷🇼",

253 "réunion": "🇷🇪",

254 "soon_arrow": "🔜",

255 "sos_button": "🆘",

256 "sagittarius": "♐",

257 "samoa": "🇼🇸",

258 "san_marino": "🇸🇲",

259 "santa_claus": "🎅",

260 "santa_claus_dark_skin_tone": "🎅🏿",

261 "santa_claus_light_skin_tone": "🎅🏻",

262 "santa_claus_medium-dark_skin_tone": "🎅🏾",

263 "santa_claus_medium-light_skin_tone": "🎅🏼",

264 "santa_claus_medium_skin_tone": "🎅🏽",

265 "saudi_arabia": "🇸🇦",

266 "scorpio": "♏",

267 "scotland": "🏴\U000e0067\U000e0062\U000e0073\U000e0063\U000e0074\U000e007f",

268 "senegal": "🇸🇳",

269 "serbia": "🇷🇸",

270 "seychelles": "🇸🇨",

271 "sierra_leone": "🇸🇱",

272 "singapore": "🇸🇬",

273 "sint_maarten": "🇸🇽",

274 "slovakia": "🇸🇰",

275 "slovenia": "🇸🇮",

276 "solomon_islands": "🇸🇧",

277 "somalia": "🇸🇴",

278 "south_africa": "🇿🇦",

279 "south_georgia_&_south_sandwich_islands": "🇬🇸",

280 "south_korea": "🇰🇷",

281 "south_sudan": "🇸🇸",

282 "spain": "🇪🇸",

283 "sri_lanka": "🇱🇰",

284 "st._barthélemy": "🇧🇱",

285 "st._helena": "🇸🇭",

286 "st._kitts_&_nevis": "🇰🇳",

287 "st._lucia": "🇱🇨",

288 "st._martin": "🇲🇫",

289 "st._pierre_&_miquelon": "🇵🇲",

290 "st._vincent_&_grenadines": "🇻🇨",

291 "statue_of_liberty": "🗽",

292 "sudan": "🇸🇩",

293 "suriname": "🇸🇷",

294 "svalbard_&_jan_mayen": "🇸🇯",

295 "swaziland": "🇸🇿",

296 "sweden": "🇸🇪",

297 "switzerland": "🇨🇭",

298 "syria": "🇸🇾",

299 "são_tomé_&_príncipe": "🇸🇹",

300 "t-rex": "🦖",

301 "top_arrow": "🔝",

302 "taiwan": "🇹🇼",

303 "tajikistan": "🇹🇯",

304 "tanzania": "🇹🇿",

305 "taurus": "♉",

306 "thailand": "🇹🇭",

307 "timor-leste": "🇹🇱",

308 "togo": "🇹🇬",

309 "tokelau": "🇹🇰",

310 "tokyo_tower": "🗼",

311 "tonga": "🇹🇴",

312 "trinidad_&_tobago": "🇹🇹",

313 "tristan_da_cunha": "🇹🇦",

314 "tunisia": "🇹🇳",

315 "turkey": "🦃",

316 "turkmenistan": "🇹🇲",

317 "turks_&_caicos_islands": "🇹🇨",

318 "tuvalu": "🇹🇻",

319 "u.s._outlying_islands": "🇺🇲",

320 "u.s._virgin_islands": "🇻🇮",

321 "up!_button": "🆙",

322 "uganda": "🇺🇬",

323 "ukraine": "🇺🇦",

324 "united_arab_emirates": "🇦🇪",

325 "united_kingdom": "🇬🇧",

326 "united_nations": "🇺🇳",

327 "united_states": "🇺🇸",

328 "uruguay": "🇺🇾",

329 "uzbekistan": "🇺🇿",

330 "vs_button": "🆚",

331 "vanuatu": "🇻🇺",

332 "vatican_city": "🇻🇦",

333 "venezuela": "🇻🇪",

334 "vietnam": "🇻🇳",

335 "virgo": "♍",

336 "wales": "🏴\U000e0067\U000e0062\U000e0077\U000e006c\U000e0073\U000e007f",

337 "wallis_&_futuna": "🇼🇫",

338 "western_sahara": "🇪🇭",

339 "yemen": "🇾🇪",

340 "zambia": "🇿🇲",

341 "zimbabwe": "🇿🇼",

342 "abacus": "🧮",

343 "adhesive_bandage": "🩹",

344 "admission_tickets": "🎟",

345 "adult": "🧑",

346 "adult_dark_skin_tone": "🧑🏿",

347 "adult_light_skin_tone": "🧑🏻",

348 "adult_medium-dark_skin_tone": "🧑🏾",

349 "adult_medium-light_skin_tone": "🧑🏼",

350 "adult_medium_skin_tone": "🧑🏽",

351 "aerial_tramway": "🚡",

352 "airplane": "✈",

353 "airplane_arrival": "🛬",

354 "airplane_departure": "🛫",

355 "alarm_clock": "⏰",

356 "alembic": "⚗",

357 "alien": "👽",

358 "alien_monster": "👾",

359 "ambulance": "🚑",

360 "american_football": "🏈",

361 "amphora": "🏺",

362 "anchor": "⚓",

363 "anger_symbol": "💢",

364 "angry_face": "😠",

365 "angry_face_with_horns": "👿",

366 "anguished_face": "😧",

367 "ant": "🐜",

368 "antenna_bars": "📶",

369 "anxious_face_with_sweat": "😰",

370 "articulated_lorry": "🚛",

371 "artist_palette": "🎨",

372 "astonished_face": "😲",

373 "atom_symbol": "⚛",

374 "auto_rickshaw": "🛺",

375 "automobile": "🚗",

376 "avocado": "🥑",

377 "axe": "🪓",

378 "baby": "👶",

379 "baby_angel": "👼",

380 "baby_angel_dark_skin_tone": "👼🏿",

381 "baby_angel_light_skin_tone": "👼🏻",

382 "baby_angel_medium-dark_skin_tone": "👼🏾",

383 "baby_angel_medium-light_skin_tone": "👼🏼",

384 "baby_angel_medium_skin_tone": "👼🏽",

385 "baby_bottle": "🍼",

386 "baby_chick": "🐤",

387 "baby_dark_skin_tone": "👶🏿",

388 "baby_light_skin_tone": "👶🏻",

389 "baby_medium-dark_skin_tone": "👶🏾",

390 "baby_medium-light_skin_tone": "👶🏼",

391 "baby_medium_skin_tone": "👶🏽",

392 "baby_symbol": "🚼",

393 "backhand_index_pointing_down": "👇",

394 "backhand_index_pointing_down_dark_skin_tone": "👇🏿",

395 "backhand_index_pointing_down_light_skin_tone": "👇🏻",

396 "backhand_index_pointing_down_medium-dark_skin_tone": "👇🏾",

397 "backhand_index_pointing_down_medium-light_skin_tone": "👇🏼",

398 "backhand_index_pointing_down_medium_skin_tone": "👇🏽",

399 "backhand_index_pointing_left": "👈",

400 "backhand_index_pointing_left_dark_skin_tone": "👈🏿",

401 "backhand_index_pointing_left_light_skin_tone": "👈🏻",

402 "backhand_index_pointing_left_medium-dark_skin_tone": "👈🏾",

403 "backhand_index_pointing_left_medium-light_skin_tone": "👈🏼",

404 "backhand_index_pointing_left_medium_skin_tone": "👈🏽",

405 "backhand_index_pointing_right": "👉",

406 "backhand_index_pointing_right_dark_skin_tone": "👉🏿",

407 "backhand_index_pointing_right_light_skin_tone": "👉🏻",

408 "backhand_index_pointing_right_medium-dark_skin_tone": "👉🏾",

409 "backhand_index_pointing_right_medium-light_skin_tone": "👉🏼",

410 "backhand_index_pointing_right_medium_skin_tone": "👉🏽",

411 "backhand_index_pointing_up": "👆",

412 "backhand_index_pointing_up_dark_skin_tone": "👆🏿",

413 "backhand_index_pointing_up_light_skin_tone": "👆🏻",

414 "backhand_index_pointing_up_medium-dark_skin_tone": "👆🏾",

415 "backhand_index_pointing_up_medium-light_skin_tone": "👆🏼",

416 "backhand_index_pointing_up_medium_skin_tone": "👆🏽",

417 "bacon": "🥓",

418 "badger": "🦡",

419 "badminton": "🏸",

420 "bagel": "🥯",

421 "baggage_claim": "🛄",

422 "baguette_bread": "🥖",

423 "balance_scale": "⚖",

424 "bald": "🦲",

425 "bald_man": "👨\u200d🦲",

426 "bald_woman": "👩\u200d🦲",

427 "ballet_shoes": "🩰",

428 "balloon": "🎈",

429 "ballot_box_with_ballot": "🗳",

430 "ballot_box_with_check": "☑",

431 "banana": "🍌",

432 "banjo": "🪕",

433 "bank": "🏦",

434 "bar_chart": "📊",

435 "barber_pole": "💈",

436 "baseball": "⚾",

437 "basket": "🧺",

438 "basketball": "🏀",

439 "bat": "🦇",

440 "bathtub": "🛁",

441 "battery": "🔋",

442 "beach_with_umbrella": "🏖",

443 "beaming_face_with_smiling_eyes": "😁",

444 "bear_face": "🐻",

445 "bearded_person": "🧔",

446 "bearded_person_dark_skin_tone": "🧔🏿",

447 "bearded_person_light_skin_tone": "🧔🏻",

448 "bearded_person_medium-dark_skin_tone": "🧔🏾",

449 "bearded_person_medium-light_skin_tone": "🧔🏼",

450 "bearded_person_medium_skin_tone": "🧔🏽",

451 "beating_heart": "💓",

452 "bed": "🛏",

453 "beer_mug": "🍺",

454 "bell": "🔔",

455 "bell_with_slash": "🔕",

456 "bellhop_bell": "🛎",

457 "bento_box": "🍱",

458 "beverage_box": "🧃",

459 "bicycle": "🚲",

460 "bikini": "👙",

461 "billed_cap": "🧢",

462 "biohazard": "☣",

463 "bird": "🐦",

464 "birthday_cake": "🎂",

465 "black_circle": "⚫",

466 "black_flag": "🏴",

467 "black_heart": "🖤",

468 "black_large_square": "⬛",

469 "black_medium-small_square": "◾",

470 "black_medium_square": "◼",

471 "black_nib": "✒",

472 "black_small_square": "▪",

473 "black_square_button": "🔲",

474 "blond-haired_man": "👱\u200d♂️",

475 "blond-haired_man_dark_skin_tone": "👱🏿\u200d♂️",

476 "blond-haired_man_light_skin_tone": "👱🏻\u200d♂️",

477 "blond-haired_man_medium-dark_skin_tone": "👱🏾\u200d♂️",

478 "blond-haired_man_medium-light_skin_tone": "👱🏼\u200d♂️",

479 "blond-haired_man_medium_skin_tone": "👱🏽\u200d♂️",

480 "blond-haired_person": "👱",

481 "blond-haired_person_dark_skin_tone": "👱🏿",

482 "blond-haired_person_light_skin_tone": "👱🏻",

483 "blond-haired_person_medium-dark_skin_tone": "👱🏾",

484 "blond-haired_person_medium-light_skin_tone": "👱🏼",

485 "blond-haired_person_medium_skin_tone": "👱🏽",

486 "blond-haired_woman": "👱\u200d♀️",

487 "blond-haired_woman_dark_skin_tone": "👱🏿\u200d♀️",

488 "blond-haired_woman_light_skin_tone": "👱🏻\u200d♀️",

489 "blond-haired_woman_medium-dark_skin_tone": "👱🏾\u200d♀️",

490 "blond-haired_woman_medium-light_skin_tone": "👱🏼\u200d♀️",

491 "blond-haired_woman_medium_skin_tone": "👱🏽\u200d♀️",

492 "blossom": "🌼",

493 "blowfish": "🐡",

494 "blue_book": "📘",

495 "blue_circle": "🔵",

496 "blue_heart": "💙",

497 "blue_square": "🟦",

498 "boar": "🐗",

499 "bomb": "💣",

500 "bone": "🦴",

501 "bookmark": "🔖",

502 "bookmark_tabs": "📑",

503 "books": "📚",

504 "bottle_with_popping_cork": "🍾",

505 "bouquet": "💐",

506 "bow_and_arrow": "🏹",

507 "bowl_with_spoon": "🥣",

508 "bowling": "🎳",

509 "boxing_glove": "🥊",

510 "boy": "👦",

511 "boy_dark_skin_tone": "👦🏿",

512 "boy_light_skin_tone": "👦🏻",

513 "boy_medium-dark_skin_tone": "👦🏾",

514 "boy_medium-light_skin_tone": "👦🏼",

515 "boy_medium_skin_tone": "👦🏽",

516 "brain": "🧠",

517 "bread": "🍞",

518 "breast-feeding": "🤱",

519 "breast-feeding_dark_skin_tone": "🤱🏿",

520 "breast-feeding_light_skin_tone": "🤱🏻",

521 "breast-feeding_medium-dark_skin_tone": "🤱🏾",

522 "breast-feeding_medium-light_skin_tone": "🤱🏼",

523 "breast-feeding_medium_skin_tone": "🤱🏽",

524 "brick": "🧱",

525 "bride_with_veil": "👰",

526 "bride_with_veil_dark_skin_tone": "👰🏿",

527 "bride_with_veil_light_skin_tone": "👰🏻",

528 "bride_with_veil_medium-dark_skin_tone": "👰🏾",

529 "bride_with_veil_medium-light_skin_tone": "👰🏼",

530 "bride_with_veil_medium_skin_tone": "👰🏽",

531 "bridge_at_night": "🌉",

532 "briefcase": "💼",

533 "briefs": "🩲",

534 "bright_button": "🔆",

535 "broccoli": "🥦",

536 "broken_heart": "💔",

537 "broom": "🧹",

538 "brown_circle": "🟤",

539 "brown_heart": "🤎",

540 "brown_square": "🟫",

541 "bug": "🐛",

542 "building_construction": "🏗",

543 "bullet_train": "🚅",

544 "burrito": "🌯",

545 "bus": "🚌",

546 "bus_stop": "🚏",

547 "bust_in_silhouette": "👤",

548 "busts_in_silhouette": "👥",

549 "butter": "🧈",

550 "butterfly": "🦋",

551 "cactus": "🌵",

552 "calendar": "📆",

553 "call_me_hand": "🤙",

554 "call_me_hand_dark_skin_tone": "🤙🏿",

555 "call_me_hand_light_skin_tone": "🤙🏻",

556 "call_me_hand_medium-dark_skin_tone": "🤙🏾",

557 "call_me_hand_medium-light_skin_tone": "🤙🏼",

558 "call_me_hand_medium_skin_tone": "🤙🏽",

559 "camel": "🐫",

560 "camera": "📷",

561 "camera_with_flash": "📸",

562 "camping": "🏕",

563 "candle": "🕯",

564 "candy": "🍬",

565 "canned_food": "🥫",

566 "canoe": "🛶",

567 "card_file_box": "🗃",

568 "card_index": "📇",

569 "card_index_dividers": "🗂",

570 "carousel_horse": "🎠",

571 "carp_streamer": "🎏",

572 "carrot": "🥕",

573 "castle": "🏰",

574 "cat": "🐱",

575 "cat_face": "🐱",

576 "cat_face_with_tears_of_joy": "😹",

577 "cat_face_with_wry_smile": "😼",

578 "chains": "⛓",

579 "chair": "🪑",

580 "chart_decreasing": "📉",

581 "chart_increasing": "📈",

582 "chart_increasing_with_yen": "💹",

583 "cheese_wedge": "🧀",

584 "chequered_flag": "🏁",

585 "cherries": "🍒",

586 "cherry_blossom": "🌸",

587 "chess_pawn": "♟",

588 "chestnut": "🌰",

589 "chicken": "🐔",

590 "child": "🧒",

591 "child_dark_skin_tone": "🧒🏿",

592 "child_light_skin_tone": "🧒🏻",

593 "child_medium-dark_skin_tone": "🧒🏾",

594 "child_medium-light_skin_tone": "🧒🏼",

595 "child_medium_skin_tone": "🧒🏽",

596 "children_crossing": "🚸",

597 "chipmunk": "🐿",

598 "chocolate_bar": "🍫",

599 "chopsticks": "🥢",

600 "church": "⛪",

601 "cigarette": "🚬",

602 "cinema": "🎦",

603 "circled_m": "Ⓜ",

604 "circus_tent": "🎪",

605 "cityscape": "🏙",

606 "cityscape_at_dusk": "🌆",

607 "clamp": "🗜",

608 "clapper_board": "🎬",

609 "clapping_hands": "👏",

610 "clapping_hands_dark_skin_tone": "👏🏿",

611 "clapping_hands_light_skin_tone": "👏🏻",

612 "clapping_hands_medium-dark_skin_tone": "👏🏾",

613 "clapping_hands_medium-light_skin_tone": "👏🏼",

614 "clapping_hands_medium_skin_tone": "👏🏽",

615 "classical_building": "🏛",

616 "clinking_beer_mugs": "🍻",

617 "clinking_glasses": "🥂",

618 "clipboard": "📋",

619 "clockwise_vertical_arrows": "🔃",

620 "closed_book": "📕",

621 "closed_mailbox_with_lowered_flag": "📪",

622 "closed_mailbox_with_raised_flag": "📫",

623 "closed_umbrella": "🌂",

624 "cloud": "☁",

625 "cloud_with_lightning": "🌩",

626 "cloud_with_lightning_and_rain": "⛈",

627 "cloud_with_rain": "🌧",

628 "cloud_with_snow": "🌨",

629 "clown_face": "🤡",

630 "club_suit": "♣",

631 "clutch_bag": "👝",

632 "coat": "🧥",

633 "cocktail_glass": "🍸",

634 "coconut": "🥥",

635 "coffin": "⚰",

636 "cold_face": "🥶",

637 "collision": "💥",

638 "comet": "☄",

639 "compass": "🧭",

640 "computer_disk": "💽",

641 "computer_mouse": "🖱",

642 "confetti_ball": "🎊",

643 "confounded_face": "😖",

644 "confused_face": "😕",

645 "construction": "🚧",

646 "construction_worker": "👷",

647 "construction_worker_dark_skin_tone": "👷🏿",

648 "construction_worker_light_skin_tone": "👷🏻",

649 "construction_worker_medium-dark_skin_tone": "👷🏾",

650 "construction_worker_medium-light_skin_tone": "👷🏼",

651 "construction_worker_medium_skin_tone": "👷🏽",

652 "control_knobs": "🎛",

653 "convenience_store": "🏪",

654 "cooked_rice": "🍚",

655 "cookie": "🍪",

656 "cooking": "🍳",

657 "copyright": "©",

658 "couch_and_lamp": "🛋",

659 "counterclockwise_arrows_button": "🔄",

660 "couple_with_heart": "💑",

661 "couple_with_heart_man_man": "👨\u200d❤️\u200d👨",

662 "couple_with_heart_woman_man": "👩\u200d❤️\u200d👨",

663 "couple_with_heart_woman_woman": "👩\u200d❤️\u200d👩",

664 "cow": "🐮",

665 "cow_face": "🐮",

666 "cowboy_hat_face": "🤠",

667 "crab": "🦀",

668 "crayon": "🖍",

669 "credit_card": "💳",

670 "crescent_moon": "🌙",

671 "cricket": "🦗",

672 "cricket_game": "🏏",

673 "crocodile": "🐊",

674 "croissant": "🥐",

675 "cross_mark": "❌",

676 "cross_mark_button": "❎",

677 "crossed_fingers": "🤞",

678 "crossed_fingers_dark_skin_tone": "🤞🏿",

679 "crossed_fingers_light_skin_tone": "🤞🏻",

680 "crossed_fingers_medium-dark_skin_tone": "🤞🏾",

681 "crossed_fingers_medium-light_skin_tone": "🤞🏼",

682 "crossed_fingers_medium_skin_tone": "🤞🏽",

683 "crossed_flags": "🎌",

684 "crossed_swords": "⚔",

685 "crown": "👑",

686 "crying_cat_face": "😿",

687 "crying_face": "😢",

688 "crystal_ball": "🔮",

689 "cucumber": "🥒",

690 "cupcake": "🧁",

691 "cup_with_straw": "🥤",

692 "curling_stone": "🥌",

693 "curly_hair": "🦱",

694 "curly-haired_man": "👨\u200d🦱",

695 "curly-haired_woman": "👩\u200d🦱",

696 "curly_loop": "➰",

697 "currency_exchange": "💱",

698 "curry_rice": "🍛",

699 "custard": "🍮",

700 "customs": "🛃",

701 "cut_of_meat": "🥩",

702 "cyclone": "🌀",

703 "dagger": "🗡",

704 "dango": "🍡",

705 "dashing_away": "💨",

706 "deaf_person": "🧏",

707 "deciduous_tree": "🌳",

708 "deer": "🦌",

709 "delivery_truck": "🚚",

710 "department_store": "🏬",

711 "derelict_house": "🏚",

712 "desert": "🏜",

713 "desert_island": "🏝",

714 "desktop_computer": "🖥",

715 "detective": "🕵",

716 "detective_dark_skin_tone": "🕵🏿",

717 "detective_light_skin_tone": "🕵🏻",

718 "detective_medium-dark_skin_tone": "🕵🏾",

719 "detective_medium-light_skin_tone": "🕵🏼",

720 "detective_medium_skin_tone": "🕵🏽",

721 "diamond_suit": "♦",

722 "diamond_with_a_dot": "💠",

723 "dim_button": "🔅",

724 "direct_hit": "🎯",

725 "disappointed_face": "😞",

726 "diving_mask": "🤿",

727 "diya_lamp": "🪔",

728 "dizzy": "💫",

729 "dizzy_face": "😵",

730 "dna": "🧬",

731 "dog": "🐶",

732 "dog_face": "🐶",

733 "dollar_banknote": "💵",

734 "dolphin": "🐬",

735 "door": "🚪",

736 "dotted_six-pointed_star": "🔯",

737 "double_curly_loop": "➿",

738 "double_exclamation_mark": "‼",

739 "doughnut": "🍩",

740 "dove": "🕊",

741 "down-left_arrow": "↙",

742 "down-right_arrow": "↘",

743 "down_arrow": "⬇",

744 "downcast_face_with_sweat": "😓",

745 "downwards_button": "🔽",

746 "dragon": "🐉",

747 "dragon_face": "🐲",

748 "dress": "👗",

749 "drooling_face": "🤤",

750 "drop_of_blood": "🩸",

751 "droplet": "💧",

752 "drum": "🥁",

753 "duck": "🦆",

754 "dumpling": "🥟",

755 "dvd": "📀",

756 "e-mail": "📧",

757 "eagle": "🦅",

758 "ear": "👂",

759 "ear_dark_skin_tone": "👂🏿",

760 "ear_light_skin_tone": "👂🏻",

761 "ear_medium-dark_skin_tone": "👂🏾",

762 "ear_medium-light_skin_tone": "👂🏼",

763 "ear_medium_skin_tone": "👂🏽",

764 "ear_of_corn": "🌽",

765 "ear_with_hearing_aid": "🦻",

766 "egg": "🍳",

767 "eggplant": "🍆",

768 "eight-pointed_star": "✴",

769 "eight-spoked_asterisk": "✳",

770 "eight-thirty": "🕣",

771 "eight_o’clock": "🕗",

772 "eject_button": "⏏",

773 "electric_plug": "🔌",

774 "elephant": "🐘",

775 "eleven-thirty": "🕦",

776 "eleven_o’clock": "🕚",

777 "elf": "🧝",

778 "elf_dark_skin_tone": "🧝🏿",

779 "elf_light_skin_tone": "🧝🏻",

780 "elf_medium-dark_skin_tone": "🧝🏾",

781 "elf_medium-light_skin_tone": "🧝🏼",

782 "elf_medium_skin_tone": "🧝🏽",

783 "envelope": "✉",

784 "envelope_with_arrow": "📩",

785 "euro_banknote": "💶",

786 "evergreen_tree": "🌲",

787 "ewe": "🐑",

788 "exclamation_mark": "❗",

789 "exclamation_question_mark": "⁉",

790 "exploding_head": "🤯",

791 "expressionless_face": "😑",

792 "eye": "👁",

793 "eye_in_speech_bubble": "👁️\u200d🗨️",

794 "eyes": "👀",

795 "face_blowing_a_kiss": "😘",

796 "face_savoring_food": "😋",

797 "face_screaming_in_fear": "😱",

798 "face_vomiting": "🤮",

799 "face_with_hand_over_mouth": "🤭",

800 "face_with_head-bandage": "🤕",

801 "face_with_medical_mask": "😷",

802 "face_with_monocle": "🧐",

803 "face_with_open_mouth": "😮",

804 "face_with_raised_eyebrow": "🤨",

805 "face_with_rolling_eyes": "🙄",

806 "face_with_steam_from_nose": "😤",

807 "face_with_symbols_on_mouth": "🤬",

808 "face_with_tears_of_joy": "😂",

809 "face_with_thermometer": "🤒",

810 "face_with_tongue": "😛",

811 "face_without_mouth": "😶",

812 "factory": "🏭",

813 "fairy": "🧚",

814 "fairy_dark_skin_tone": "🧚🏿",

815 "fairy_light_skin_tone": "🧚🏻",

816 "fairy_medium-dark_skin_tone": "🧚🏾",

817 "fairy_medium-light_skin_tone": "🧚🏼",

818 "fairy_medium_skin_tone": "🧚🏽",

819 "falafel": "🧆",

820 "fallen_leaf": "🍂",

821 "family": "👪",

822 "family_man_boy": "👨\u200d👦",

823 "family_man_boy_boy": "👨\u200d👦\u200d👦",

824 "family_man_girl": "👨\u200d👧",

825 "family_man_girl_boy": "👨\u200d👧\u200d👦",

826 "family_man_girl_girl": "👨\u200d👧\u200d👧",

827 "family_man_man_boy": "👨\u200d👨\u200d👦",

828 "family_man_man_boy_boy": "👨\u200d👨\u200d👦\u200d👦",

829 "family_man_man_girl": "👨\u200d👨\u200d👧",

830 "family_man_man_girl_boy": "👨\u200d👨\u200d👧\u200d👦",

831 "family_man_man_girl_girl": "👨\u200d👨\u200d👧\u200d👧",

832 "family_man_woman_boy": "👨\u200d👩\u200d👦",

833 "family_man_woman_boy_boy": "👨\u200d👩\u200d👦\u200d👦",

834 "family_man_woman_girl": "👨\u200d👩\u200d👧",

835 "family_man_woman_girl_boy": "👨\u200d👩\u200d👧\u200d👦",

836 "family_man_woman_girl_girl": "👨\u200d👩\u200d👧\u200d👧",

837 "family_woman_boy": "👩\u200d👦",

838 "family_woman_boy_boy": "👩\u200d👦\u200d👦",

839 "family_woman_girl": "👩\u200d👧",

840 "family_woman_girl_boy": "👩\u200d👧\u200d👦",

841 "family_woman_girl_girl": "👩\u200d👧\u200d👧",

842 "family_woman_woman_boy": "👩\u200d👩\u200d👦",

843 "family_woman_woman_boy_boy": "👩\u200d👩\u200d👦\u200d👦",

844 "family_woman_woman_girl": "👩\u200d👩\u200d👧",

845 "family_woman_woman_girl_boy": "👩\u200d👩\u200d👧\u200d👦",

846 "family_woman_woman_girl_girl": "👩\u200d👩\u200d👧\u200d👧",

847 "fast-forward_button": "⏩",

848 "fast_down_button": "⏬",

849 "fast_reverse_button": "⏪",

850 "fast_up_button": "⏫",

851 "fax_machine": "📠",

852 "fearful_face": "😨",

853 "female_sign": "♀",

854 "ferris_wheel": "🎡",

855 "ferry": "⛴",

856 "field_hockey": "🏑",

857 "file_cabinet": "🗄",

858 "file_folder": "📁",

859 "film_frames": "🎞",

860 "film_projector": "📽",

861 "fire": "🔥",

862 "fire_extinguisher": "🧯",

863 "firecracker": "🧨",

864 "fire_engine": "🚒",

865 "fireworks": "🎆",

866 "first_quarter_moon": "🌓",

867 "first_quarter_moon_face": "🌛",

868 "fish": "🐟",

869 "fish_cake_with_swirl": "🍥",

870 "fishing_pole": "🎣",

871 "five-thirty": "🕠",

872 "five_o’clock": "🕔",

873 "flag_in_hole": "⛳",

874 "flamingo": "🦩",

875 "flashlight": "🔦",

876 "flat_shoe": "🥿",

877 "fleur-de-lis": "⚜",

878 "flexed_biceps": "💪",

879 "flexed_biceps_dark_skin_tone": "💪🏿",

880 "flexed_biceps_light_skin_tone": "💪🏻",

881 "flexed_biceps_medium-dark_skin_tone": "💪🏾",

882 "flexed_biceps_medium-light_skin_tone": "💪🏼",

883 "flexed_biceps_medium_skin_tone": "💪🏽",

884 "floppy_disk": "💾",

885 "flower_playing_cards": "🎴",

886 "flushed_face": "😳",

887 "flying_disc": "🥏",

888 "flying_saucer": "🛸",

889 "fog": "🌫",

890 "foggy": "🌁",

891 "folded_hands": "🙏",

892 "folded_hands_dark_skin_tone": "🙏🏿",

893 "folded_hands_light_skin_tone": "🙏🏻",

894 "folded_hands_medium-dark_skin_tone": "🙏🏾",

895 "folded_hands_medium-light_skin_tone": "🙏🏼",

896 "folded_hands_medium_skin_tone": "🙏🏽",

897 "foot": "🦶",

898 "footprints": "👣",

899 "fork_and_knife": "🍴",

900 "fork_and_knife_with_plate": "🍽",

901 "fortune_cookie": "🥠",

902 "fountain": "⛲",

903 "fountain_pen": "🖋",

904 "four-thirty": "🕟",

905 "four_leaf_clover": "🍀",

906 "four_o’clock": "🕓",

907 "fox_face": "🦊",

908 "framed_picture": "🖼",

909 "french_fries": "🍟",

910 "fried_shrimp": "🍤",

911 "frog_face": "🐸",

912 "front-facing_baby_chick": "🐥",

913 "frowning_face": "☹",

914 "frowning_face_with_open_mouth": "😦",

915 "fuel_pump": "⛽",

916 "full_moon": "🌕",

917 "full_moon_face": "🌝",

918 "funeral_urn": "⚱",

919 "game_die": "🎲",

920 "garlic": "🧄",

921 "gear": "⚙",

922 "gem_stone": "💎",

923 "genie": "🧞",

924 "ghost": "👻",

925 "giraffe": "🦒",

926 "girl": "👧",

927 "girl_dark_skin_tone": "👧🏿",

928 "girl_light_skin_tone": "👧🏻",

929 "girl_medium-dark_skin_tone": "👧🏾",

930 "girl_medium-light_skin_tone": "👧🏼",

931 "girl_medium_skin_tone": "👧🏽",

932 "glass_of_milk": "🥛",

933 "glasses": "👓",

934 "globe_showing_americas": "🌎",

935 "globe_showing_asia-australia": "🌏",

936 "globe_showing_europe-africa": "🌍",

937 "globe_with_meridians": "🌐",

938 "gloves": "🧤",

939 "glowing_star": "🌟",

940 "goal_net": "🥅",

941 "goat": "🐐",

942 "goblin": "👺",

943 "goggles": "🥽",

944 "gorilla": "🦍",

945 "graduation_cap": "🎓",

946 "grapes": "🍇",

947 "green_apple": "🍏",

948 "green_book": "📗",

949 "green_circle": "🟢",

950 "green_heart": "💚",

951 "green_salad": "🥗",

952 "green_square": "🟩",

953 "grimacing_face": "😬",

954 "grinning_cat_face": "😺",

955 "grinning_cat_face_with_smiling_eyes": "😸",

956 "grinning_face": "😀",

957 "grinning_face_with_big_eyes": "😃",

958 "grinning_face_with_smiling_eyes": "😄",

959 "grinning_face_with_sweat": "😅",

960 "grinning_squinting_face": "😆",

961 "growing_heart": "💗",

962 "guard": "💂",

963 "guard_dark_skin_tone": "💂🏿",

964 "guard_light_skin_tone": "💂🏻",

965 "guard_medium-dark_skin_tone": "💂🏾",

966 "guard_medium-light_skin_tone": "💂🏼",

967 "guard_medium_skin_tone": "💂🏽",

968 "guide_dog": "🦮",

969 "guitar": "🎸",

970 "hamburger": "🍔",

971 "hammer": "🔨",

972 "hammer_and_pick": "⚒",

973 "hammer_and_wrench": "🛠",

974 "hamster_face": "🐹",

975 "hand_with_fingers_splayed": "🖐",

976 "hand_with_fingers_splayed_dark_skin_tone": "🖐🏿",

977 "hand_with_fingers_splayed_light_skin_tone": "🖐🏻",

978 "hand_with_fingers_splayed_medium-dark_skin_tone": "🖐🏾",

979 "hand_with_fingers_splayed_medium-light_skin_tone": "🖐🏼",

980 "hand_with_fingers_splayed_medium_skin_tone": "🖐🏽",

981 "handbag": "👜",

982 "handshake": "🤝",

983 "hatching_chick": "🐣",

984 "headphone": "🎧",

985 "hear-no-evil_monkey": "🙉",

986 "heart_decoration": "💟",

987 "heart_suit": "♥",

988 "heart_with_arrow": "💘",

989 "heart_with_ribbon": "💝",

990 "heavy_check_mark": "✔",

991 "heavy_division_sign": "➗",

992 "heavy_dollar_sign": "💲",

993 "heavy_heart_exclamation": "❣",

994 "heavy_large_circle": "⭕",

995 "heavy_minus_sign": "➖",

996 "heavy_multiplication_x": "✖",

997 "heavy_plus_sign": "➕",

998 "hedgehog": "🦔",

999 "helicopter": "🚁",

1000 "herb": "🌿",

1001 "hibiscus": "🌺",

1002 "high-heeled_shoe": "👠",

1003 "high-speed_train": "🚄",

1004 "high_voltage": "⚡",

1005 "hiking_boot": "🥾",

1006 "hindu_temple": "🛕",

1007 "hippopotamus": "🦛",

1008 "hole": "🕳",

1009 "honey_pot": "🍯",

1010 "honeybee": "🐝",

1011 "horizontal_traffic_light": "🚥",

1012 "horse": "🐴",

1013 "horse_face": "🐴",

1014 "horse_racing": "🏇",

1015 "horse_racing_dark_skin_tone": "🏇🏿",

1016 "horse_racing_light_skin_tone": "🏇🏻",

1017 "horse_racing_medium-dark_skin_tone": "🏇🏾",

1018 "horse_racing_medium-light_skin_tone": "🏇🏼",

1019 "horse_racing_medium_skin_tone": "🏇🏽",

1020 "hospital": "🏥",

1021 "hot_beverage": "☕",

1022 "hot_dog": "🌭",

1023 "hot_face": "🥵",

1024 "hot_pepper": "🌶",

1025 "hot_springs": "♨",

1026 "hotel": "🏨",

1027 "hourglass_done": "⌛",

1028 "hourglass_not_done": "⏳",

1029 "house": "🏠",

1030 "house_with_garden": "🏡",

1031 "houses": "🏘",

1032 "hugging_face": "🤗",

1033 "hundred_points": "💯",

1034 "hushed_face": "😯",

1035 "ice": "🧊",

1036 "ice_cream": "🍨",

1037 "ice_hockey": "🏒",

1038 "ice_skate": "⛸",

1039 "inbox_tray": "📥",

1040 "incoming_envelope": "📨",

1041 "index_pointing_up": "☝",

1042 "index_pointing_up_dark_skin_tone": "☝🏿",

1043 "index_pointing_up_light_skin_tone": "☝🏻",

1044 "index_pointing_up_medium-dark_skin_tone": "☝🏾",

1045 "index_pointing_up_medium-light_skin_tone": "☝🏼",

1046 "index_pointing_up_medium_skin_tone": "☝🏽",

1047 "infinity": "♾",

1048 "information": "ℹ",

1049 "input_latin_letters": "🔤",

1050 "input_latin_lowercase": "🔡",

1051 "input_latin_uppercase": "🔠",

1052 "input_numbers": "🔢",

1053 "input_symbols": "🔣",

1054 "jack-o-lantern": "🎃",

1055 "jeans": "👖",

1056 "jigsaw": "🧩",

1057 "joker": "🃏",

1058 "joystick": "🕹",

1059 "kaaba": "🕋",

1060 "kangaroo": "🦘",

1061 "key": "🔑",

1062 "keyboard": "⌨",

1063 "keycap_#": "#️⃣",

1064 "keycap_*": "*️⃣",

1065 "keycap_0": "0️⃣",

1066 "keycap_1": "1️⃣",

1067 "keycap_10": "🔟",

1068 "keycap_2": "2️⃣",

1069 "keycap_3": "3️⃣",

1070 "keycap_4": "4️⃣",

1071 "keycap_5": "5️⃣",

1072 "keycap_6": "6️⃣",

1073 "keycap_7": "7️⃣",

1074 "keycap_8": "8️⃣",

1075 "keycap_9": "9️⃣",

1076 "kick_scooter": "🛴",

1077 "kimono": "👘",

1078 "kiss": "💋",

1079 "kiss_man_man": "👨\u200d❤️\u200d💋\u200d👨",

1080 "kiss_mark": "💋",

1081 "kiss_woman_man": "👩\u200d❤️\u200d💋\u200d👨",

1082 "kiss_woman_woman": "👩\u200d❤️\u200d💋\u200d👩",

1083 "kissing_cat_face": "😽",

1084 "kissing_face": "😗",

1085 "kissing_face_with_closed_eyes": "😚",

1086 "kissing_face_with_smiling_eyes": "😙",

1087 "kitchen_knife": "🔪",

1088 "kite": "🪁",

1089 "kiwi_fruit": "🥝",

1090 "koala": "🐨",

1091 "lab_coat": "🥼",

1092 "label": "🏷",

1093 "lacrosse": "🥍",

1094 "lady_beetle": "🐞",

1095 "laptop_computer": "💻",

1096 "large_blue_diamond": "🔷",

1097 "large_orange_diamond": "🔶",

1098 "last_quarter_moon": "🌗",

1099 "last_quarter_moon_face": "🌜",

1100 "last_track_button": "⏮",

1101 "latin_cross": "✝",

1102 "leaf_fluttering_in_wind": "🍃",

1103 "leafy_green": "🥬",

1104 "ledger": "📒",

1105 "left-facing_fist": "🤛",

1106 "left-facing_fist_dark_skin_tone": "🤛🏿",

1107 "left-facing_fist_light_skin_tone": "🤛🏻",

1108 "left-facing_fist_medium-dark_skin_tone": "🤛🏾",

1109 "left-facing_fist_medium-light_skin_tone": "🤛🏼",

1110 "left-facing_fist_medium_skin_tone": "🤛🏽",

1111 "left-right_arrow": "↔",

1112 "left_arrow": "⬅",

1113 "left_arrow_curving_right": "↪",

1114 "left_luggage": "🛅",

1115 "left_speech_bubble": "🗨",

1116 "leg": "🦵",

1117 "lemon": "🍋",

1118 "leopard": "🐆",

1119 "level_slider": "🎚",

1120 "light_bulb": "💡",

1121 "light_rail": "🚈",

1122 "link": "🔗",

1123 "linked_paperclips": "🖇",

1124 "lion_face": "🦁",

1125 "lipstick": "💄",

1126 "litter_in_bin_sign": "🚮",

1127 "lizard": "🦎",

1128 "llama": "🦙",

1129 "lobster": "🦞",

1130 "locked": "🔒",

1131 "locked_with_key": "🔐",

1132 "locked_with_pen": "🔏",

1133 "locomotive": "🚂",

1134 "lollipop": "🍭",

1135 "lotion_bottle": "🧴",

1136 "loudly_crying_face": "😭",

1137 "loudspeaker": "📢",

1138 "love-you_gesture": "🤟",

1139 "love-you_gesture_dark_skin_tone": "🤟🏿",

1140 "love-you_gesture_light_skin_tone": "🤟🏻",

1141 "love-you_gesture_medium-dark_skin_tone": "🤟🏾",

1142 "love-you_gesture_medium-light_skin_tone": "🤟🏼",

1143 "love-you_gesture_medium_skin_tone": "🤟🏽",

1144 "love_hotel": "🏩",

1145 "love_letter": "💌",

1146 "luggage": "🧳",

1147 "lying_face": "🤥",

1148 "mage": "🧙",

1149 "mage_dark_skin_tone": "🧙🏿",

1150 "mage_light_skin_tone": "🧙🏻",

1151 "mage_medium-dark_skin_tone": "🧙🏾",

1152 "mage_medium-light_skin_tone": "🧙🏼",

1153 "mage_medium_skin_tone": "🧙🏽",

1154 "magnet": "🧲",

1155 "magnifying_glass_tilted_left": "🔍",

1156 "magnifying_glass_tilted_right": "🔎",

1157 "mahjong_red_dragon": "🀄",

1158 "male_sign": "♂",

1159 "man": "👨",

1160 "man_and_woman_holding_hands": "👫",

1161 "man_artist": "👨\u200d🎨",

1162 "man_artist_dark_skin_tone": "👨🏿\u200d🎨",

1163 "man_artist_light_skin_tone": "👨🏻\u200d🎨",

1164 "man_artist_medium-dark_skin_tone": "👨🏾\u200d🎨",

1165 "man_artist_medium-light_skin_tone": "👨🏼\u200d🎨",

1166 "man_artist_medium_skin_tone": "👨🏽\u200d🎨",

1167 "man_astronaut": "👨\u200d🚀",

1168 "man_astronaut_dark_skin_tone": "👨🏿\u200d🚀",

1169 "man_astronaut_light_skin_tone": "👨🏻\u200d🚀",

1170 "man_astronaut_medium-dark_skin_tone": "👨🏾\u200d🚀",

1171 "man_astronaut_medium-light_skin_tone": "👨🏼\u200d🚀",

1172 "man_astronaut_medium_skin_tone": "👨🏽\u200d🚀",

1173 "man_biking": "🚴\u200d♂️",

1174 "man_biking_dark_skin_tone": "🚴🏿\u200d♂️",

1175 "man_biking_light_skin_tone": "🚴🏻\u200d♂️",

1176 "man_biking_medium-dark_skin_tone": "🚴🏾\u200d♂️",

1177 "man_biking_medium-light_skin_tone": "🚴🏼\u200d♂️",

1178 "man_biking_medium_skin_tone": "🚴🏽\u200d♂️",

1179 "man_bouncing_ball": "⛹️\u200d♂️",

1180 "man_bouncing_ball_dark_skin_tone": "⛹🏿\u200d♂️",

1181 "man_bouncing_ball_light_skin_tone": "⛹🏻\u200d♂️",

1182 "man_bouncing_ball_medium-dark_skin_tone": "⛹🏾\u200d♂️",

1183 "man_bouncing_ball_medium-light_skin_tone": "⛹🏼\u200d♂️",

1184 "man_bouncing_ball_medium_skin_tone": "⛹🏽\u200d♂️",

1185 "man_bowing": "🙇\u200d♂️",

1186 "man_bowing_dark_skin_tone": "🙇🏿\u200d♂️",

1187 "man_bowing_light_skin_tone": "🙇🏻\u200d♂️",

1188 "man_bowing_medium-dark_skin_tone": "🙇🏾\u200d♂️",

1189 "man_bowing_medium-light_skin_tone": "🙇🏼\u200d♂️",

1190 "man_bowing_medium_skin_tone": "🙇🏽\u200d♂️",

1191 "man_cartwheeling": "🤸\u200d♂️",

1192 "man_cartwheeling_dark_skin_tone": "🤸🏿\u200d♂️",

1193 "man_cartwheeling_light_skin_tone": "🤸🏻\u200d♂️",

1194 "man_cartwheeling_medium-dark_skin_tone": "🤸🏾\u200d♂️",

1195 "man_cartwheeling_medium-light_skin_tone": "🤸🏼\u200d♂️",

1196 "man_cartwheeling_medium_skin_tone": "🤸🏽\u200d♂️",

1197 "man_climbing": "🧗\u200d♂️",

1198 "man_climbing_dark_skin_tone": "🧗🏿\u200d♂️",

1199 "man_climbing_light_skin_tone": "🧗🏻\u200d♂️",

1200 "man_climbing_medium-dark_skin_tone": "🧗🏾\u200d♂️",

1201 "man_climbing_medium-light_skin_tone": "🧗🏼\u200d♂️",

1202 "man_climbing_medium_skin_tone": "🧗🏽\u200d♂️",

1203 "man_construction_worker": "👷\u200d♂️",

1204 "man_construction_worker_dark_skin_tone": "👷🏿\u200d♂️",

1205 "man_construction_worker_light_skin_tone": "👷🏻\u200d♂️",

1206 "man_construction_worker_medium-dark_skin_tone": "👷🏾\u200d♂️",

1207 "man_construction_worker_medium-light_skin_tone": "👷🏼\u200d♂️",

1208 "man_construction_worker_medium_skin_tone": "👷🏽\u200d♂️",

1209 "man_cook": "👨\u200d🍳",

1210 "man_cook_dark_skin_tone": "👨🏿\u200d🍳",

1211 "man_cook_light_skin_tone": "👨🏻\u200d🍳",

1212 "man_cook_medium-dark_skin_tone": "👨🏾\u200d🍳",

1213 "man_cook_medium-light_skin_tone": "👨🏼\u200d🍳",

1214 "man_cook_medium_skin_tone": "👨🏽\u200d🍳",

1215 "man_dancing": "🕺",

1216 "man_dancing_dark_skin_tone": "🕺🏿",

1217 "man_dancing_light_skin_tone": "🕺🏻",

1218 "man_dancing_medium-dark_skin_tone": "🕺🏾",

1219 "man_dancing_medium-light_skin_tone": "🕺🏼",

1220 "man_dancing_medium_skin_tone": "🕺🏽",

1221 "man_dark_skin_tone": "👨🏿",

1222 "man_detective": "🕵️\u200d♂️",

1223 "man_detective_dark_skin_tone": "🕵🏿\u200d♂️",

1224 "man_detective_light_skin_tone": "🕵🏻\u200d♂️",

1225 "man_detective_medium-dark_skin_tone": "🕵🏾\u200d♂️",

1226 "man_detective_medium-light_skin_tone": "🕵🏼\u200d♂️",

1227 "man_detective_medium_skin_tone": "🕵🏽\u200d♂️",

1228 "man_elf": "🧝\u200d♂️",

1229 "man_elf_dark_skin_tone": "🧝🏿\u200d♂️",

1230 "man_elf_light_skin_tone": "🧝🏻\u200d♂️",

1231 "man_elf_medium-dark_skin_tone": "🧝🏾\u200d♂️",

1232 "man_elf_medium-light_skin_tone": "🧝🏼\u200d♂️",

1233 "man_elf_medium_skin_tone": "🧝🏽\u200d♂️",

1234 "man_facepalming": "🤦\u200d♂️",

1235 "man_facepalming_dark_skin_tone": "🤦🏿\u200d♂️",

1236 "man_facepalming_light_skin_tone": "🤦🏻\u200d♂️",

1237 "man_facepalming_medium-dark_skin_tone": "🤦🏾\u200d♂️",

1238 "man_facepalming_medium-light_skin_tone": "🤦🏼\u200d♂️",

1239 "man_facepalming_medium_skin_tone": "🤦🏽\u200d♂️",

1240 "man_factory_worker": "👨\u200d🏭",

1241 "man_factory_worker_dark_skin_tone": "👨🏿\u200d🏭",

1242 "man_factory_worker_light_skin_tone": "👨🏻\u200d🏭",

1243 "man_factory_worker_medium-dark_skin_tone": "👨🏾\u200d🏭",

1244 "man_factory_worker_medium-light_skin_tone": "👨🏼\u200d🏭",

1245 "man_factory_worker_medium_skin_tone": "👨🏽\u200d🏭",

1246 "man_fairy": "🧚\u200d♂️",

1247 "man_fairy_dark_skin_tone": "🧚🏿\u200d♂️",

1248 "man_fairy_light_skin_tone": "🧚🏻\u200d♂️",

1249 "man_fairy_medium-dark_skin_tone": "🧚🏾\u200d♂️",

1250 "man_fairy_medium-light_skin_tone": "🧚🏼\u200d♂️",

1251 "man_fairy_medium_skin_tone": "🧚🏽\u200d♂️",

1252 "man_farmer": "👨\u200d🌾",

1253 "man_farmer_dark_skin_tone": "👨🏿\u200d🌾",

1254 "man_farmer_light_skin_tone": "👨🏻\u200d🌾",

1255 "man_farmer_medium-dark_skin_tone": "👨🏾\u200d🌾",

1256 "man_farmer_medium-light_skin_tone": "👨🏼\u200d🌾",

1257 "man_farmer_medium_skin_tone": "👨🏽\u200d🌾",

1258 "man_firefighter": "👨\u200d🚒",

1259 "man_firefighter_dark_skin_tone": "👨🏿\u200d🚒",

1260 "man_firefighter_light_skin_tone": "👨🏻\u200d🚒",

1261 "man_firefighter_medium-dark_skin_tone": "👨🏾\u200d🚒",

1262 "man_firefighter_medium-light_skin_tone": "👨🏼\u200d🚒",

1263 "man_firefighter_medium_skin_tone": "👨🏽\u200d🚒",

1264 "man_frowning": "🙍\u200d♂️",

1265 "man_frowning_dark_skin_tone": "🙍🏿\u200d♂️",

1266 "man_frowning_light_skin_tone": "🙍🏻\u200d♂️",

1267 "man_frowning_medium-dark_skin_tone": "🙍🏾\u200d♂️",

1268 "man_frowning_medium-light_skin_tone": "🙍🏼\u200d♂️",

1269 "man_frowning_medium_skin_tone": "🙍🏽\u200d♂️",

1270 "man_genie": "🧞\u200d♂️",

1271 "man_gesturing_no": "🙅\u200d♂️",

1272 "man_gesturing_no_dark_skin_tone": "🙅🏿\u200d♂️",

1273 "man_gesturing_no_light_skin_tone": "🙅🏻\u200d♂️",

1274 "man_gesturing_no_medium-dark_skin_tone": "🙅🏾\u200d♂️",

1275 "man_gesturing_no_medium-light_skin_tone": "🙅🏼\u200d♂️",

1276 "man_gesturing_no_medium_skin_tone": "🙅🏽\u200d♂️",

1277 "man_gesturing_ok": "🙆\u200d♂️",

1278 "man_gesturing_ok_dark_skin_tone": "🙆🏿\u200d♂️",

1279 "man_gesturing_ok_light_skin_tone": "🙆🏻\u200d♂️",

1280 "man_gesturing_ok_medium-dark_skin_tone": "🙆🏾\u200d♂️",

1281 "man_gesturing_ok_medium-light_skin_tone": "🙆🏼\u200d♂️",

1282 "man_gesturing_ok_medium_skin_tone": "🙆🏽\u200d♂️",

1283 "man_getting_haircut": "💇\u200d♂️",

1284 "man_getting_haircut_dark_skin_tone": "💇🏿\u200d♂️",

1285 "man_getting_haircut_light_skin_tone": "💇🏻\u200d♂️",

1286 "man_getting_haircut_medium-dark_skin_tone": "💇🏾\u200d♂️",

1287 "man_getting_haircut_medium-light_skin_tone": "💇🏼\u200d♂️",

1288 "man_getting_haircut_medium_skin_tone": "💇🏽\u200d♂️",

1289 "man_getting_massage": "💆\u200d♂️",

1290 "man_getting_massage_dark_skin_tone": "💆🏿\u200d♂️",

1291 "man_getting_massage_light_skin_tone": "💆🏻\u200d♂️",

1292 "man_getting_massage_medium-dark_skin_tone": "💆🏾\u200d♂️",

1293 "man_getting_massage_medium-light_skin_tone": "💆🏼\u200d♂️",

1294 "man_getting_massage_medium_skin_tone": "💆🏽\u200d♂️",

1295 "man_golfing": "🏌️\u200d♂️",

1296 "man_golfing_dark_skin_tone": "🏌🏿\u200d♂️",

1297 "man_golfing_light_skin_tone": "🏌🏻\u200d♂️",

1298 "man_golfing_medium-dark_skin_tone": "🏌🏾\u200d♂️",

1299 "man_golfing_medium-light_skin_tone": "🏌🏼\u200d♂️",

1300 "man_golfing_medium_skin_tone": "🏌🏽\u200d♂️",

1301 "man_guard": "💂\u200d♂️",

1302 "man_guard_dark_skin_tone": "💂🏿\u200d♂️",

1303 "man_guard_light_skin_tone": "💂🏻\u200d♂️",

1304 "man_guard_medium-dark_skin_tone": "💂🏾\u200d♂️",

1305 "man_guard_medium-light_skin_tone": "💂🏼\u200d♂️",

1306 "man_guard_medium_skin_tone": "💂🏽\u200d♂️",

1307 "man_health_worker": "👨\u200d⚕️",

1308 "man_health_worker_dark_skin_tone": "👨🏿\u200d⚕️",

1309 "man_health_worker_light_skin_tone": "👨🏻\u200d⚕️",

1310 "man_health_worker_medium-dark_skin_tone": "👨🏾\u200d⚕️",

1311 "man_health_worker_medium-light_skin_tone": "👨🏼\u200d⚕️",

1312 "man_health_worker_medium_skin_tone": "👨🏽\u200d⚕️",

1313 "man_in_lotus_position": "🧘\u200d♂️",

1314 "man_in_lotus_position_dark_skin_tone": "🧘🏿\u200d♂️",

1315 "man_in_lotus_position_light_skin_tone": "🧘🏻\u200d♂️",

1316 "man_in_lotus_position_medium-dark_skin_tone": "🧘🏾\u200d♂️",

1317 "man_in_lotus_position_medium-light_skin_tone": "🧘🏼\u200d♂️",

1318 "man_in_lotus_position_medium_skin_tone": "🧘🏽\u200d♂️",

1319 "man_in_manual_wheelchair": "👨\u200d🦽",

1320 "man_in_motorized_wheelchair": "👨\u200d🦼",

1321 "man_in_steamy_room": "🧖\u200d♂️",

1322 "man_in_steamy_room_dark_skin_tone": "🧖🏿\u200d♂️",

1323 "man_in_steamy_room_light_skin_tone": "🧖🏻\u200d♂️",

1324 "man_in_steamy_room_medium-dark_skin_tone": "🧖🏾\u200d♂️",

1325 "man_in_steamy_room_medium-light_skin_tone": "🧖🏼\u200d♂️",

1326 "man_in_steamy_room_medium_skin_tone": "🧖🏽\u200d♂️",

1327 "man_in_suit_levitating": "🕴",

1328 "man_in_suit_levitating_dark_skin_tone": "🕴🏿",

1329 "man_in_suit_levitating_light_skin_tone": "🕴🏻",

1330 "man_in_suit_levitating_medium-dark_skin_tone": "🕴🏾",

1331 "man_in_suit_levitating_medium-light_skin_tone": "🕴🏼",

1332 "man_in_suit_levitating_medium_skin_tone": "🕴🏽",

1333 "man_in_tuxedo": "🤵",

1334 "man_in_tuxedo_dark_skin_tone": "🤵🏿",

1335 "man_in_tuxedo_light_skin_tone": "🤵🏻",

1336 "man_in_tuxedo_medium-dark_skin_tone": "🤵🏾",

1337 "man_in_tuxedo_medium-light_skin_tone": "🤵🏼",

1338 "man_in_tuxedo_medium_skin_tone": "🤵🏽",

1339 "man_judge": "👨\u200d⚖️",

1340 "man_judge_dark_skin_tone": "👨🏿\u200d⚖️",

1341 "man_judge_light_skin_tone": "👨🏻\u200d⚖️",

1342 "man_judge_medium-dark_skin_tone": "👨🏾\u200d⚖️",

1343 "man_judge_medium-light_skin_tone": "👨🏼\u200d⚖️",

1344 "man_judge_medium_skin_tone": "👨🏽\u200d⚖️",

1345 "man_juggling": "🤹\u200d♂️",

1346 "man_juggling_dark_skin_tone": "🤹🏿\u200d♂️",

1347 "man_juggling_light_skin_tone": "🤹🏻\u200d♂️",

1348 "man_juggling_medium-dark_skin_tone": "🤹🏾\u200d♂️",

1349 "man_juggling_medium-light_skin_tone": "🤹🏼\u200d♂️",

1350 "man_juggling_medium_skin_tone": "🤹🏽\u200d♂️",

1351 "man_lifting_weights": "🏋️\u200d♂️",

1352 "man_lifting_weights_dark_skin_tone": "🏋🏿\u200d♂️",

1353 "man_lifting_weights_light_skin_tone": "🏋🏻\u200d♂️",

1354 "man_lifting_weights_medium-dark_skin_tone": "🏋🏾\u200d♂️",

1355 "man_lifting_weights_medium-light_skin_tone": "🏋🏼\u200d♂️",

1356 "man_lifting_weights_medium_skin_tone": "🏋🏽\u200d♂️",

1357 "man_light_skin_tone": "👨🏻",

1358 "man_mage": "🧙\u200d♂️",

1359 "man_mage_dark_skin_tone": "🧙🏿\u200d♂️",

1360 "man_mage_light_skin_tone": "🧙🏻\u200d♂️",

1361 "man_mage_medium-dark_skin_tone": "🧙🏾\u200d♂️",

1362 "man_mage_medium-light_skin_tone": "🧙🏼\u200d♂️",

1363 "man_mage_medium_skin_tone": "🧙🏽\u200d♂️",

1364 "man_mechanic": "👨\u200d🔧",

1365 "man_mechanic_dark_skin_tone": "👨🏿\u200d🔧",

1366 "man_mechanic_light_skin_tone": "👨🏻\u200d🔧",

1367 "man_mechanic_medium-dark_skin_tone": "👨🏾\u200d🔧",

1368 "man_mechanic_medium-light_skin_tone": "👨🏼\u200d🔧",

1369 "man_mechanic_medium_skin_tone": "👨🏽\u200d🔧",

1370 "man_medium-dark_skin_tone": "👨🏾",

1371 "man_medium-light_skin_tone": "👨🏼",

1372 "man_medium_skin_tone": "👨🏽",

1373 "man_mountain_biking": "🚵\u200d♂️",

1374 "man_mountain_biking_dark_skin_tone": "🚵🏿\u200d♂️",

1375 "man_mountain_biking_light_skin_tone": "🚵🏻\u200d♂️",

1376 "man_mountain_biking_medium-dark_skin_tone": "🚵🏾\u200d♂️",

1377 "man_mountain_biking_medium-light_skin_tone": "🚵🏼\u200d♂️",

1378 "man_mountain_biking_medium_skin_tone": "🚵🏽\u200d♂️",

1379 "man_office_worker": "👨\u200d💼",

1380 "man_office_worker_dark_skin_tone": "👨🏿\u200d💼",

1381 "man_office_worker_light_skin_tone": "👨🏻\u200d💼",

1382 "man_office_worker_medium-dark_skin_tone": "👨🏾\u200d💼",

1383 "man_office_worker_medium-light_skin_tone": "👨🏼\u200d💼",

1384 "man_office_worker_medium_skin_tone": "👨🏽\u200d💼",

1385 "man_pilot": "👨\u200d✈️",

1386 "man_pilot_dark_skin_tone": "👨🏿\u200d✈️",

1387 "man_pilot_light_skin_tone": "👨🏻\u200d✈️",

1388 "man_pilot_medium-dark_skin_tone": "👨🏾\u200d✈️",

1389 "man_pilot_medium-light_skin_tone": "👨🏼\u200d✈️",

1390 "man_pilot_medium_skin_tone": "👨🏽\u200d✈️",

1391 "man_playing_handball": "🤾\u200d♂️",

1392 "man_playing_handball_dark_skin_tone": "🤾🏿\u200d♂️",

1393 "man_playing_handball_light_skin_tone": "🤾🏻\u200d♂️",

1394 "man_playing_handball_medium-dark_skin_tone": "🤾🏾\u200d♂️",

1395 "man_playing_handball_medium-light_skin_tone": "🤾🏼\u200d♂️",

1396 "man_playing_handball_medium_skin_tone": "🤾🏽\u200d♂️",

1397 "man_playing_water_polo": "🤽\u200d♂️",

1398 "man_playing_water_polo_dark_skin_tone": "🤽🏿\u200d♂️",

1399 "man_playing_water_polo_light_skin_tone": "🤽🏻\u200d♂️",

1400 "man_playing_water_polo_medium-dark_skin_tone": "🤽🏾\u200d♂️",

1401 "man_playing_water_polo_medium-light_skin_tone": "🤽🏼\u200d♂️",

1402 "man_playing_water_polo_medium_skin_tone": "🤽🏽\u200d♂️",

1403 "man_police_officer": "👮\u200d♂️",

1404 "man_police_officer_dark_skin_tone": "👮🏿\u200d♂️",

1405 "man_police_officer_light_skin_tone": "👮🏻\u200d♂️",

1406 "man_police_officer_medium-dark_skin_tone": "👮🏾\u200d♂️",

1407 "man_police_officer_medium-light_skin_tone": "👮🏼\u200d♂️",

1408 "man_police_officer_medium_skin_tone": "👮🏽\u200d♂️",

1409 "man_pouting": "🙎\u200d♂️",

1410 "man_pouting_dark_skin_tone": "🙎🏿\u200d♂️",

1411 "man_pouting_light_skin_tone": "🙎🏻\u200d♂️",

1412 "man_pouting_medium-dark_skin_tone": "🙎🏾\u200d♂️",

1413 "man_pouting_medium-light_skin_tone": "🙎🏼\u200d♂️",

1414 "man_pouting_medium_skin_tone": "🙎🏽\u200d♂️",

1415 "man_raising_hand": "🙋\u200d♂️",

1416 "man_raising_hand_dark_skin_tone": "🙋🏿\u200d♂️",

1417 "man_raising_hand_light_skin_tone": "🙋🏻\u200d♂️",

1418 "man_raising_hand_medium-dark_skin_tone": "🙋🏾\u200d♂️",

1419 "man_raising_hand_medium-light_skin_tone": "🙋🏼\u200d♂️",

1420 "man_raising_hand_medium_skin_tone": "🙋🏽\u200d♂️",

1421 "man_rowing_boat": "🚣\u200d♂️",

1422 "man_rowing_boat_dark_skin_tone": "🚣🏿\u200d♂️",

1423 "man_rowing_boat_light_skin_tone": "🚣🏻\u200d♂️",

1424 "man_rowing_boat_medium-dark_skin_tone": "🚣🏾\u200d♂️",

1425 "man_rowing_boat_medium-light_skin_tone": "🚣🏼\u200d♂️",

1426 "man_rowing_boat_medium_skin_tone": "🚣🏽\u200d♂️",

1427 "man_running": "🏃\u200d♂️",

1428 "man_running_dark_skin_tone": "🏃🏿\u200d♂️",

1429 "man_running_light_skin_tone": "🏃🏻\u200d♂️",

1430 "man_running_medium-dark_skin_tone": "🏃🏾\u200d♂️",

1431 "man_running_medium-light_skin_tone": "🏃🏼\u200d♂️",

1432 "man_running_medium_skin_tone": "🏃🏽\u200d♂️",

1433 "man_scientist": "👨\u200d🔬",

1434 "man_scientist_dark_skin_tone": "👨🏿\u200d🔬",

1435 "man_scientist_light_skin_tone": "👨🏻\u200d🔬",

1436 "man_scientist_medium-dark_skin_tone": "👨🏾\u200d🔬",

1437 "man_scientist_medium-light_skin_tone": "👨🏼\u200d🔬",

1438 "man_scientist_medium_skin_tone": "👨🏽\u200d🔬",

1439 "man_shrugging": "🤷\u200d♂️",

1440 "man_shrugging_dark_skin_tone": "🤷🏿\u200d♂️",

1441 "man_shrugging_light_skin_tone": "🤷🏻\u200d♂️",

1442 "man_shrugging_medium-dark_skin_tone": "🤷🏾\u200d♂️",

1443 "man_shrugging_medium-light_skin_tone": "🤷🏼\u200d♂️",

1444 "man_shrugging_medium_skin_tone": "🤷🏽\u200d♂️",

1445 "man_singer": "👨\u200d🎤",

1446 "man_singer_dark_skin_tone": "👨🏿\u200d🎤",

1447 "man_singer_light_skin_tone": "👨🏻\u200d🎤",

1448 "man_singer_medium-dark_skin_tone": "👨🏾\u200d🎤",

1449 "man_singer_medium-light_skin_tone": "👨🏼\u200d🎤",

1450 "man_singer_medium_skin_tone": "👨🏽\u200d🎤",

1451 "man_student": "👨\u200d🎓",

1452 "man_student_dark_skin_tone": "👨🏿\u200d🎓",

1453 "man_student_light_skin_tone": "👨🏻\u200d🎓",

1454 "man_student_medium-dark_skin_tone": "👨🏾\u200d🎓",

1455 "man_student_medium-light_skin_tone": "👨🏼\u200d🎓",

1456 "man_student_medium_skin_tone": "👨🏽\u200d🎓",

1457 "man_surfing": "🏄\u200d♂️",

1458 "man_surfing_dark_skin_tone": "🏄🏿\u200d♂️",

1459 "man_surfing_light_skin_tone": "🏄🏻\u200d♂️",

1460 "man_surfing_medium-dark_skin_tone": "🏄🏾\u200d♂️",

1461 "man_surfing_medium-light_skin_tone": "🏄🏼\u200d♂️",

1462 "man_surfing_medium_skin_tone": "🏄🏽\u200d♂️",

1463 "man_swimming": "🏊\u200d♂️",

1464 "man_swimming_dark_skin_tone": "🏊🏿\u200d♂️",

1465 "man_swimming_light_skin_tone": "🏊🏻\u200d♂️",

1466 "man_swimming_medium-dark_skin_tone": "🏊🏾\u200d♂️",

1467 "man_swimming_medium-light_skin_tone": "🏊🏼\u200d♂️",

1468 "man_swimming_medium_skin_tone": "🏊🏽\u200d♂️",

1469 "man_teacher": "👨\u200d🏫",

1470 "man_teacher_dark_skin_tone": "👨🏿\u200d🏫",

1471 "man_teacher_light_skin_tone": "👨🏻\u200d🏫",

1472 "man_teacher_medium-dark_skin_tone": "👨🏾\u200d🏫",

1473 "man_teacher_medium-light_skin_tone": "👨🏼\u200d🏫",

1474 "man_teacher_medium_skin_tone": "👨🏽\u200d🏫",

1475 "man_technologist": "👨\u200d💻",

1476 "man_technologist_dark_skin_tone": "👨🏿\u200d💻",

1477 "man_technologist_light_skin_tone": "👨🏻\u200d💻",

1478 "man_technologist_medium-dark_skin_tone": "👨🏾\u200d💻",

1479 "man_technologist_medium-light_skin_tone": "👨🏼\u200d💻",

1480 "man_technologist_medium_skin_tone": "👨🏽\u200d💻",

1481 "man_tipping_hand": "💁\u200d♂️",

1482 "man_tipping_hand_dark_skin_tone": "💁🏿\u200d♂️",

1483 "man_tipping_hand_light_skin_tone": "💁🏻\u200d♂️",

1484 "man_tipping_hand_medium-dark_skin_tone": "💁🏾\u200d♂️",

1485 "man_tipping_hand_medium-light_skin_tone": "💁🏼\u200d♂️",

1486 "man_tipping_hand_medium_skin_tone": "💁🏽\u200d♂️",

1487 "man_vampire": "🧛\u200d♂️",

1488 "man_vampire_dark_skin_tone": "🧛🏿\u200d♂️",

1489 "man_vampire_light_skin_tone": "🧛🏻\u200d♂️",

1490 "man_vampire_medium-dark_skin_tone": "🧛🏾\u200d♂️",

1491 "man_vampire_medium-light_skin_tone": "🧛🏼\u200d♂️",

1492 "man_vampire_medium_skin_tone": "🧛🏽\u200d♂️",

1493 "man_walking": "🚶\u200d♂️",

1494 "man_walking_dark_skin_tone": "🚶🏿\u200d♂️",

1495 "man_walking_light_skin_tone": "🚶🏻\u200d♂️",

1496 "man_walking_medium-dark_skin_tone": "🚶🏾\u200d♂️",

1497 "man_walking_medium-light_skin_tone": "🚶🏼\u200d♂️",

1498 "man_walking_medium_skin_tone": "🚶🏽\u200d♂️",

1499 "man_wearing_turban": "👳\u200d♂️",

1500 "man_wearing_turban_dark_skin_tone": "👳🏿\u200d♂️",

1501 "man_wearing_turban_light_skin_tone": "👳🏻\u200d♂️",

1502 "man_wearing_turban_medium-dark_skin_tone": "👳🏾\u200d♂️",

1503 "man_wearing_turban_medium-light_skin_tone": "👳🏼\u200d♂️",

1504 "man_wearing_turban_medium_skin_tone": "👳🏽\u200d♂️",

1505 "man_with_probing_cane": "👨\u200d🦯",

1506 "man_with_chinese_cap": "👲",

1507 "man_with_chinese_cap_dark_skin_tone": "👲🏿",

1508 "man_with_chinese_cap_light_skin_tone": "👲🏻",

1509 "man_with_chinese_cap_medium-dark_skin_tone": "👲🏾",

1510 "man_with_chinese_cap_medium-light_skin_tone": "👲🏼",

1511 "man_with_chinese_cap_medium_skin_tone": "👲🏽",

1512 "man_zombie": "🧟\u200d♂️",

1513 "mango": "🥭",

1514 "mantelpiece_clock": "🕰",

1515 "manual_wheelchair": "🦽",

1516 "man’s_shoe": "👞",

1517 "map_of_japan": "🗾",

1518 "maple_leaf": "🍁",

1519 "martial_arts_uniform": "🥋",

1520 "mate": "🧉",

1521 "meat_on_bone": "🍖",

1522 "mechanical_arm": "🦾",

1523 "mechanical_leg": "🦿",

1524 "medical_symbol": "⚕",

1525 "megaphone": "📣",

1526 "melon": "🍈",

1527 "memo": "📝",

1528 "men_with_bunny_ears": "👯\u200d♂️",

1529 "men_wrestling": "🤼\u200d♂️",

1530 "menorah": "🕎",

1531 "men’s_room": "🚹",

1532 "mermaid": "🧜\u200d♀️",

1533 "mermaid_dark_skin_tone": "🧜🏿\u200d♀️",

1534 "mermaid_light_skin_tone": "🧜🏻\u200d♀️",

1535 "mermaid_medium-dark_skin_tone": "🧜🏾\u200d♀️",

1536 "mermaid_medium-light_skin_tone": "🧜🏼\u200d♀️",

1537 "mermaid_medium_skin_tone": "🧜🏽\u200d♀️",

1538 "merman": "🧜\u200d♂️",

1539 "merman_dark_skin_tone": "🧜🏿\u200d♂️",

1540 "merman_light_skin_tone": "🧜🏻\u200d♂️",

1541 "merman_medium-dark_skin_tone": "🧜🏾\u200d♂️",

1542 "merman_medium-light_skin_tone": "🧜🏼\u200d♂️",

1543 "merman_medium_skin_tone": "🧜🏽\u200d♂️",

1544 "merperson": "🧜",

1545 "merperson_dark_skin_tone": "🧜🏿",

1546 "merperson_light_skin_tone": "🧜🏻",

1547 "merperson_medium-dark_skin_tone": "🧜🏾",

1548 "merperson_medium-light_skin_tone": "🧜🏼",

1549 "merperson_medium_skin_tone": "🧜🏽",

1550 "metro": "🚇",

1551 "microbe": "🦠",

1552 "microphone": "🎤",

1553 "microscope": "🔬",

1554 "middle_finger": "🖕",

1555 "middle_finger_dark_skin_tone": "🖕🏿",

1556 "middle_finger_light_skin_tone": "🖕🏻",

1557 "middle_finger_medium-dark_skin_tone": "🖕🏾",

1558 "middle_finger_medium-light_skin_tone": "🖕🏼",

1559 "middle_finger_medium_skin_tone": "🖕🏽",

1560 "military_medal": "🎖",

1561 "milky_way": "🌌",

1562 "minibus": "🚐",

1563 "moai": "🗿",

1564 "mobile_phone": "📱",

1565 "mobile_phone_off": "📴",

1566 "mobile_phone_with_arrow": "📲",

1567 "money-mouth_face": "🤑",

1568 "money_bag": "💰",

1569 "money_with_wings": "💸",

1570 "monkey": "🐒",

1571 "monkey_face": "🐵",

1572 "monorail": "🚝",

1573 "moon_cake": "🥮",

1574 "moon_viewing_ceremony": "🎑",

1575 "mosque": "🕌",

1576 "mosquito": "🦟",

1577 "motor_boat": "🛥",

1578 "motor_scooter": "🛵",

1579 "motorcycle": "🏍",

1580 "motorized_wheelchair": "🦼",

1581 "motorway": "🛣",

1582 "mount_fuji": "🗻",

1583 "mountain": "⛰",

1584 "mountain_cableway": "🚠",

1585 "mountain_railway": "🚞",

1586 "mouse": "🐭",

1587 "mouse_face": "🐭",

1588 "mouth": "👄",

1589 "movie_camera": "🎥",

1590 "mushroom": "🍄",

1591 "musical_keyboard": "🎹",

1592 "musical_note": "🎵",

1593 "musical_notes": "🎶",

1594 "musical_score": "🎼",

1595 "muted_speaker": "🔇",

1596 "nail_polish": "💅",

1597 "nail_polish_dark_skin_tone": "💅🏿",

1598 "nail_polish_light_skin_tone": "💅🏻",

1599 "nail_polish_medium-dark_skin_tone": "💅🏾",

1600 "nail_polish_medium-light_skin_tone": "💅🏼",

1601 "nail_polish_medium_skin_tone": "💅🏽",

1602 "name_badge": "📛",

1603 "national_park": "🏞",

1604 "nauseated_face": "🤢",

1605 "nazar_amulet": "🧿",

1606 "necktie": "👔",

1607 "nerd_face": "🤓",

1608 "neutral_face": "😐",

1609 "new_moon": "🌑",

1610 "new_moon_face": "🌚",

1611 "newspaper": "📰",

1612 "next_track_button": "⏭",

1613 "night_with_stars": "🌃",

1614 "nine-thirty": "🕤",

1615 "nine_o’clock": "🕘",

1616 "no_bicycles": "🚳",

1617 "no_entry": "⛔",

1618 "no_littering": "🚯",

1619 "no_mobile_phones": "📵",

1620 "no_one_under_eighteen": "🔞",

1621 "no_pedestrians": "🚷",

1622 "no_smoking": "🚭",

1623 "non-potable_water": "🚱",

1624 "nose": "👃",

1625 "nose_dark_skin_tone": "👃🏿",

1626 "nose_light_skin_tone": "👃🏻",

1627 "nose_medium-dark_skin_tone": "👃🏾",

1628 "nose_medium-light_skin_tone": "👃🏼",

1629 "nose_medium_skin_tone": "👃🏽",

1630 "notebook": "📓",

1631 "notebook_with_decorative_cover": "📔",

1632 "nut_and_bolt": "🔩",

1633 "octopus": "🐙",

1634 "oden": "🍢",

1635 "office_building": "🏢",

1636 "ogre": "👹",

1637 "oil_drum": "🛢",

1638 "old_key": "🗝",

1639 "old_man": "👴",

1640 "old_man_dark_skin_tone": "👴🏿",

1641 "old_man_light_skin_tone": "👴🏻",

1642 "old_man_medium-dark_skin_tone": "👴🏾",

1643 "old_man_medium-light_skin_tone": "👴🏼",

1644 "old_man_medium_skin_tone": "👴🏽",

1645 "old_woman": "👵",

1646 "old_woman_dark_skin_tone": "👵🏿",

1647 "old_woman_light_skin_tone": "👵🏻",

1648 "old_woman_medium-dark_skin_tone": "👵🏾",

1649 "old_woman_medium-light_skin_tone": "👵🏼",

1650 "old_woman_medium_skin_tone": "👵🏽",

1651 "older_adult": "🧓",

1652 "older_adult_dark_skin_tone": "🧓🏿",

1653 "older_adult_light_skin_tone": "🧓🏻",

1654 "older_adult_medium-dark_skin_tone": "🧓🏾",

1655 "older_adult_medium-light_skin_tone": "🧓🏼",

1656 "older_adult_medium_skin_tone": "🧓🏽",

1657 "om": "🕉",

1658 "oncoming_automobile": "🚘",

1659 "oncoming_bus": "🚍",

1660 "oncoming_fist": "👊",

1661 "oncoming_fist_dark_skin_tone": "👊🏿",

1662 "oncoming_fist_light_skin_tone": "👊🏻",

1663 "oncoming_fist_medium-dark_skin_tone": "👊🏾",

1664 "oncoming_fist_medium-light_skin_tone": "👊🏼",

1665 "oncoming_fist_medium_skin_tone": "👊🏽",

1666 "oncoming_police_car": "🚔",

1667 "oncoming_taxi": "🚖",

1668 "one-piece_swimsuit": "🩱",

1669 "one-thirty": "🕜",

1670 "one_o’clock": "🕐",

1671 "onion": "🧅",

1672 "open_book": "📖",

1673 "open_file_folder": "📂",

1674 "open_hands": "👐",

1675 "open_hands_dark_skin_tone": "👐🏿",

1676 "open_hands_light_skin_tone": "👐🏻",

1677 "open_hands_medium-dark_skin_tone": "👐🏾",

1678 "open_hands_medium-light_skin_tone": "👐🏼",

1679 "open_hands_medium_skin_tone": "👐🏽",

1680 "open_mailbox_with_lowered_flag": "📭",

1681 "open_mailbox_with_raised_flag": "📬",

1682 "optical_disk": "💿",

1683 "orange_book": "📙",

1684 "orange_circle": "🟠",

1685 "orange_heart": "🧡",

1686 "orange_square": "🟧",

1687 "orangutan": "🦧",

1688 "orthodox_cross": "☦",

1689 "otter": "🦦",

1690 "outbox_tray": "📤",

1691 "owl": "🦉",

1692 "ox": "🐂",

1693 "oyster": "🦪",

1694 "package": "📦",

1695 "page_facing_up": "📄",

1696 "page_with_curl": "📃",

1697 "pager": "📟",

1698 "paintbrush": "🖌",

1699 "palm_tree": "🌴",

1700 "palms_up_together": "🤲",

1701 "palms_up_together_dark_skin_tone": "🤲🏿",

1702 "palms_up_together_light_skin_tone": "🤲🏻",

1703 "palms_up_together_medium-dark_skin_tone": "🤲🏾",

1704 "palms_up_together_medium-light_skin_tone": "🤲🏼",

1705 "palms_up_together_medium_skin_tone": "🤲🏽",

1706 "pancakes": "🥞",

1707 "panda_face": "🐼",

1708 "paperclip": "📎",

1709 "parrot": "🦜",

1710 "part_alternation_mark": "〽",

1711 "party_popper": "🎉",

1712 "partying_face": "🥳",

1713 "passenger_ship": "🛳",

1714 "passport_control": "🛂",

1715 "pause_button": "⏸",

1716 "paw_prints": "🐾",

1717 "peace_symbol": "☮",

1718 "peach": "🍑",

1719 "peacock": "🦚",

1720 "peanuts": "🥜",

1721 "pear": "🍐",

1722 "pen": "🖊",

1723 "pencil": "📝",

1724 "penguin": "🐧",

1725 "pensive_face": "😔",

1726 "people_holding_hands": "🧑\u200d🤝\u200d🧑",

1727 "people_with_bunny_ears": "👯",

1728 "people_wrestling": "🤼",

1729 "performing_arts": "🎭",

1730 "persevering_face": "😣",

1731 "person_biking": "🚴",

1732 "person_biking_dark_skin_tone": "🚴🏿",

1733 "person_biking_light_skin_tone": "🚴🏻",

1734 "person_biking_medium-dark_skin_tone": "🚴🏾",

1735 "person_biking_medium-light_skin_tone": "🚴🏼",

1736 "person_biking_medium_skin_tone": "🚴🏽",

1737 "person_bouncing_ball": "⛹",

1738 "person_bouncing_ball_dark_skin_tone": "⛹🏿",

1739 "person_bouncing_ball_light_skin_tone": "⛹🏻",

1740 "person_bouncing_ball_medium-dark_skin_tone": "⛹🏾",

1741 "person_bouncing_ball_medium-light_skin_tone": "⛹🏼",

1742 "person_bouncing_ball_medium_skin_tone": "⛹🏽",

1743 "person_bowing": "🙇",

1744 "person_bowing_dark_skin_tone": "🙇🏿",

1745 "person_bowing_light_skin_tone": "🙇🏻",

1746 "person_bowing_medium-dark_skin_tone": "🙇🏾",

1747 "person_bowing_medium-light_skin_tone": "🙇🏼",

1748 "person_bowing_medium_skin_tone": "🙇🏽",

1749 "person_cartwheeling": "🤸",

1750 "person_cartwheeling_dark_skin_tone": "🤸🏿",

1751 "person_cartwheeling_light_skin_tone": "🤸🏻",

1752 "person_cartwheeling_medium-dark_skin_tone": "🤸🏾",

1753 "person_cartwheeling_medium-light_skin_tone": "🤸🏼",

1754 "person_cartwheeling_medium_skin_tone": "🤸🏽",

1755 "person_climbing": "🧗",

1756 "person_climbing_dark_skin_tone": "🧗🏿",

1757 "person_climbing_light_skin_tone": "🧗🏻",

1758 "person_climbing_medium-dark_skin_tone": "🧗🏾",

1759 "person_climbing_medium-light_skin_tone": "🧗🏼",

1760 "person_climbing_medium_skin_tone": "🧗🏽",

1761 "person_facepalming": "🤦",

1762 "person_facepalming_dark_skin_tone": "🤦🏿",

1763 "person_facepalming_light_skin_tone": "🤦🏻",

1764 "person_facepalming_medium-dark_skin_tone": "🤦🏾",

1765 "person_facepalming_medium-light_skin_tone": "🤦🏼",

1766 "person_facepalming_medium_skin_tone": "🤦🏽",

1767 "person_fencing": "🤺",

1768 "person_frowning": "🙍",

1769 "person_frowning_dark_skin_tone": "🙍🏿",

1770 "person_frowning_light_skin_tone": "🙍🏻",

1771 "person_frowning_medium-dark_skin_tone": "🙍🏾",

1772 "person_frowning_medium-light_skin_tone": "🙍🏼",

1773 "person_frowning_medium_skin_tone": "🙍🏽",

1774 "person_gesturing_no": "🙅",

1775 "person_gesturing_no_dark_skin_tone": "🙅🏿",

1776 "person_gesturing_no_light_skin_tone": "🙅🏻",

1777 "person_gesturing_no_medium-dark_skin_tone": "🙅🏾",

1778 "person_gesturing_no_medium-light_skin_tone": "🙅🏼",

1779 "person_gesturing_no_medium_skin_tone": "🙅🏽",

1780 "person_gesturing_ok": "🙆",

1781 "person_gesturing_ok_dark_skin_tone": "🙆🏿",

1782 "person_gesturing_ok_light_skin_tone": "🙆🏻",

1783 "person_gesturing_ok_medium-dark_skin_tone": "🙆🏾",

1784 "person_gesturing_ok_medium-light_skin_tone": "🙆🏼",

1785 "person_gesturing_ok_medium_skin_tone": "🙆🏽",

1786 "person_getting_haircut": "💇",

1787 "person_getting_haircut_dark_skin_tone": "💇🏿",

1788 "person_getting_haircut_light_skin_tone": "💇🏻",

1789 "person_getting_haircut_medium-dark_skin_tone": "💇🏾",

1790 "person_getting_haircut_medium-light_skin_tone": "💇🏼",

1791 "person_getting_haircut_medium_skin_tone": "💇🏽",

1792 "person_getting_massage": "💆",

1793 "person_getting_massage_dark_skin_tone": "💆🏿",

1794 "person_getting_massage_light_skin_tone": "💆🏻",

1795 "person_getting_massage_medium-dark_skin_tone": "💆🏾",

1796 "person_getting_massage_medium-light_skin_tone": "💆🏼",

1797 "person_getting_massage_medium_skin_tone": "💆🏽",

1798 "person_golfing": "🏌",

1799 "person_golfing_dark_skin_tone": "🏌🏿",

1800 "person_golfing_light_skin_tone": "🏌🏻",

1801 "person_golfing_medium-dark_skin_tone": "🏌🏾",

1802 "person_golfing_medium-light_skin_tone": "🏌🏼",

1803 "person_golfing_medium_skin_tone": "🏌🏽",

1804 "person_in_bed": "🛌",

1805 "person_in_bed_dark_skin_tone": "🛌🏿",

1806 "person_in_bed_light_skin_tone": "🛌🏻",

1807 "person_in_bed_medium-dark_skin_tone": "🛌🏾",

1808 "person_in_bed_medium-light_skin_tone": "🛌🏼",

1809 "person_in_bed_medium_skin_tone": "🛌🏽",

1810 "person_in_lotus_position": "🧘",

1811 "person_in_lotus_position_dark_skin_tone": "🧘🏿",

1812 "person_in_lotus_position_light_skin_tone": "🧘🏻",

1813 "person_in_lotus_position_medium-dark_skin_tone": "🧘🏾",

1814 "person_in_lotus_position_medium-light_skin_tone": "🧘🏼",

1815 "person_in_lotus_position_medium_skin_tone": "🧘🏽",

1816 "person_in_steamy_room": "🧖",

1817 "person_in_steamy_room_dark_skin_tone": "🧖🏿",

1818 "person_in_steamy_room_light_skin_tone": "🧖🏻",

1819 "person_in_steamy_room_medium-dark_skin_tone": "🧖🏾",

1820 "person_in_steamy_room_medium-light_skin_tone": "🧖🏼",

1821 "person_in_steamy_room_medium_skin_tone": "🧖🏽",

1822 "person_juggling": "🤹",

1823 "person_juggling_dark_skin_tone": "🤹🏿",

1824 "person_juggling_light_skin_tone": "🤹🏻",

1825 "person_juggling_medium-dark_skin_tone": "🤹🏾",

1826 "person_juggling_medium-light_skin_tone": "🤹🏼",

1827 "person_juggling_medium_skin_tone": "🤹🏽",

1828 "person_kneeling": "🧎",

1829 "person_lifting_weights": "🏋",

1830 "person_lifting_weights_dark_skin_tone": "🏋🏿",

1831 "person_lifting_weights_light_skin_tone": "🏋🏻",

1832 "person_lifting_weights_medium-dark_skin_tone": "🏋🏾",

1833 "person_lifting_weights_medium-light_skin_tone": "🏋🏼",

1834 "person_lifting_weights_medium_skin_tone": "🏋🏽",

1835 "person_mountain_biking": "🚵",

1836 "person_mountain_biking_dark_skin_tone": "🚵🏿",

1837 "person_mountain_biking_light_skin_tone": "🚵🏻",

1838 "person_mountain_biking_medium-dark_skin_tone": "🚵🏾",

1839 "person_mountain_biking_medium-light_skin_tone": "🚵🏼",

1840 "person_mountain_biking_medium_skin_tone": "🚵🏽",

1841 "person_playing_handball": "🤾",

1842 "person_playing_handball_dark_skin_tone": "🤾🏿",

1843 "person_playing_handball_light_skin_tone": "🤾🏻",

1844 "person_playing_handball_medium-dark_skin_tone": "🤾🏾",

1845 "person_playing_handball_medium-light_skin_tone": "🤾🏼",

1846 "person_playing_handball_medium_skin_tone": "🤾🏽",

1847 "person_playing_water_polo": "🤽",

1848 "person_playing_water_polo_dark_skin_tone": "🤽🏿",

1849 "person_playing_water_polo_light_skin_tone": "🤽🏻",

1850 "person_playing_water_polo_medium-dark_skin_tone": "🤽🏾",

1851 "person_playing_water_polo_medium-light_skin_tone": "🤽🏼",

1852 "person_playing_water_polo_medium_skin_tone": "🤽🏽",

1853 "person_pouting": "🙎",

1854 "person_pouting_dark_skin_tone": "🙎🏿",

1855 "person_pouting_light_skin_tone": "🙎🏻",

1856 "person_pouting_medium-dark_skin_tone": "🙎🏾",

1857 "person_pouting_medium-light_skin_tone": "🙎🏼",

1858 "person_pouting_medium_skin_tone": "🙎🏽",

1859 "person_raising_hand": "🙋",

1860 "person_raising_hand_dark_skin_tone": "🙋🏿",

1861 "person_raising_hand_light_skin_tone": "🙋🏻",

1862 "person_raising_hand_medium-dark_skin_tone": "🙋🏾",

1863 "person_raising_hand_medium-light_skin_tone": "🙋🏼",

1864 "person_raising_hand_medium_skin_tone": "🙋🏽",

1865 "person_rowing_boat": "🚣",

1866 "person_rowing_boat_dark_skin_tone": "🚣🏿",

1867 "person_rowing_boat_light_skin_tone": "🚣🏻",

1868 "person_rowing_boat_medium-dark_skin_tone": "🚣🏾",

1869 "person_rowing_boat_medium-light_skin_tone": "🚣🏼",

1870 "person_rowing_boat_medium_skin_tone": "🚣🏽",

1871 "person_running": "🏃",

1872 "person_running_dark_skin_tone": "🏃🏿",

1873 "person_running_light_skin_tone": "🏃🏻",

1874 "person_running_medium-dark_skin_tone": "🏃🏾",

1875 "person_running_medium-light_skin_tone": "🏃🏼",

1876 "person_running_medium_skin_tone": "🏃🏽",

1877 "person_shrugging": "🤷",

1878 "person_shrugging_dark_skin_tone": "🤷🏿",

1879 "person_shrugging_light_skin_tone": "🤷🏻",

1880 "person_shrugging_medium-dark_skin_tone": "🤷🏾",

1881 "person_shrugging_medium-light_skin_tone": "🤷🏼",

1882 "person_shrugging_medium_skin_tone": "🤷🏽",

1883 "person_standing": "🧍",

1884 "person_surfing": "🏄",

1885 "person_surfing_dark_skin_tone": "🏄🏿",

1886 "person_surfing_light_skin_tone": "🏄🏻",

1887 "person_surfing_medium-dark_skin_tone": "🏄🏾",

1888 "person_surfing_medium-light_skin_tone": "🏄🏼",

1889 "person_surfing_medium_skin_tone": "🏄🏽",

1890 "person_swimming": "🏊",

1891 "person_swimming_dark_skin_tone": "🏊🏿",

1892 "person_swimming_light_skin_tone": "🏊🏻",

1893 "person_swimming_medium-dark_skin_tone": "🏊🏾",

1894 "person_swimming_medium-light_skin_tone": "🏊🏼",

1895 "person_swimming_medium_skin_tone": "🏊🏽",

1896 "person_taking_bath": "🛀",

1897 "person_taking_bath_dark_skin_tone": "🛀🏿",

1898 "person_taking_bath_light_skin_tone": "🛀🏻",

1899 "person_taking_bath_medium-dark_skin_tone": "🛀🏾",

1900 "person_taking_bath_medium-light_skin_tone": "🛀🏼",

1901 "person_taking_bath_medium_skin_tone": "🛀🏽",

1902 "person_tipping_hand": "💁",

1903 "person_tipping_hand_dark_skin_tone": "💁🏿",

1904 "person_tipping_hand_light_skin_tone": "💁🏻",

1905 "person_tipping_hand_medium-dark_skin_tone": "💁🏾",

1906 "person_tipping_hand_medium-light_skin_tone": "💁🏼",

1907 "person_tipping_hand_medium_skin_tone": "💁🏽",

1908 "person_walking": "🚶",

1909 "person_walking_dark_skin_tone": "🚶🏿",

1910 "person_walking_light_skin_tone": "🚶🏻",

1911 "person_walking_medium-dark_skin_tone": "🚶🏾",

1912 "person_walking_medium-light_skin_tone": "🚶🏼",

1913 "person_walking_medium_skin_tone": "🚶🏽",

1914 "person_wearing_turban": "👳",

1915 "person_wearing_turban_dark_skin_tone": "👳🏿",

1916 "person_wearing_turban_light_skin_tone": "👳🏻",

1917 "person_wearing_turban_medium-dark_skin_tone": "👳🏾",

1918 "person_wearing_turban_medium-light_skin_tone": "👳🏼",

1919 "person_wearing_turban_medium_skin_tone": "👳🏽",

1920 "petri_dish": "🧫",

1921 "pick": "⛏",

1922 "pie": "🥧",

1923 "pig": "🐷",

1924 "pig_face": "🐷",

1925 "pig_nose": "🐽",

1926 "pile_of_poo": "💩",

1927 "pill": "💊",

1928 "pinching_hand": "🤏",

1929 "pine_decoration": "🎍",

1930 "pineapple": "🍍",

1931 "ping_pong": "🏓",

1932 "pirate_flag": "🏴\u200d☠️",

1933 "pistol": "🔫",

1934 "pizza": "🍕",

1935 "place_of_worship": "🛐",

1936 "play_button": "▶",

1937 "play_or_pause_button": "⏯",

1938 "pleading_face": "🥺",

1939 "police_car": "🚓",

1940 "police_car_light": "🚨",

1941 "police_officer": "👮",

1942 "police_officer_dark_skin_tone": "👮🏿",

1943 "police_officer_light_skin_tone": "👮🏻",

1944 "police_officer_medium-dark_skin_tone": "👮🏾",

1945 "police_officer_medium-light_skin_tone": "👮🏼",

1946 "police_officer_medium_skin_tone": "👮🏽",

1947 "poodle": "🐩",

1948 "pool_8_ball": "🎱",

1949 "popcorn": "🍿",

1950 "post_office": "🏣",

1951 "postal_horn": "📯",

1952 "postbox": "📮",

1953 "pot_of_food": "🍲",

1954 "potable_water": "🚰",

1955 "potato": "🥔",

1956 "poultry_leg": "🍗",

1957 "pound_banknote": "💷",

1958 "pouting_cat_face": "😾",

1959 "pouting_face": "😡",

1960 "prayer_beads": "📿",

1961 "pregnant_woman": "🤰",

1962 "pregnant_woman_dark_skin_tone": "🤰🏿",

1963 "pregnant_woman_light_skin_tone": "🤰🏻",

1964 "pregnant_woman_medium-dark_skin_tone": "🤰🏾",

1965 "pregnant_woman_medium-light_skin_tone": "🤰🏼",

1966 "pregnant_woman_medium_skin_tone": "🤰🏽",

1967 "pretzel": "🥨",

1968 "probing_cane": "🦯",

1969 "prince": "🤴",

1970 "prince_dark_skin_tone": "🤴🏿",

1971 "prince_light_skin_tone": "🤴🏻",

1972 "prince_medium-dark_skin_tone": "🤴🏾",

1973 "prince_medium-light_skin_tone": "🤴🏼",

1974 "prince_medium_skin_tone": "🤴🏽",

1975 "princess": "👸",

1976 "princess_dark_skin_tone": "👸🏿",

1977 "princess_light_skin_tone": "👸🏻",

1978 "princess_medium-dark_skin_tone": "👸🏾",

1979 "princess_medium-light_skin_tone": "👸🏼",

1980 "princess_medium_skin_tone": "👸🏽",

1981 "printer": "🖨",

1982 "prohibited": "🚫",

1983 "purple_circle": "🟣",

1984 "purple_heart": "💜",

1985 "purple_square": "🟪",

1986 "purse": "👛",

1987 "pushpin": "📌",

1988 "question_mark": "❓",

1989 "rabbit": "🐰",

1990 "rabbit_face": "🐰",

1991 "raccoon": "🦝",

1992 "racing_car": "🏎",

1993 "radio": "📻",

1994 "radio_button": "🔘",

1995 "radioactive": "☢",

1996 "railway_car": "🚃",

1997 "railway_track": "🛤",

1998 "rainbow": "🌈",

1999 "rainbow_flag": "🏳️\u200d🌈",

2000 "raised_back_of_hand": "🤚",

2001 "raised_back_of_hand_dark_skin_tone": "🤚🏿",

2002 "raised_back_of_hand_light_skin_tone": "🤚🏻",

2003 "raised_back_of_hand_medium-dark_skin_tone": "🤚🏾",

2004 "raised_back_of_hand_medium-light_skin_tone": "🤚🏼",

2005 "raised_back_of_hand_medium_skin_tone": "🤚🏽",

2006 "raised_fist": "✊",

2007 "raised_fist_dark_skin_tone": "✊🏿",

2008 "raised_fist_light_skin_tone": "✊🏻",

2009 "raised_fist_medium-dark_skin_tone": "✊🏾",

2010 "raised_fist_medium-light_skin_tone": "✊🏼",

2011 "raised_fist_medium_skin_tone": "✊🏽",

2012 "raised_hand": "✋",

2013 "raised_hand_dark_skin_tone": "✋🏿",

2014 "raised_hand_light_skin_tone": "✋🏻",

2015 "raised_hand_medium-dark_skin_tone": "✋🏾",

2016 "raised_hand_medium-light_skin_tone": "✋🏼",

2017 "raised_hand_medium_skin_tone": "✋🏽",

2018 "raising_hands": "🙌",

2019 "raising_hands_dark_skin_tone": "🙌🏿",

2020 "raising_hands_light_skin_tone": "🙌🏻",

2021 "raising_hands_medium-dark_skin_tone": "🙌🏾",

2022 "raising_hands_medium-light_skin_tone": "🙌🏼",

2023 "raising_hands_medium_skin_tone": "🙌🏽",

2024 "ram": "🐏",

2025 "rat": "🐀",

2026 "razor": "🪒",

2027 "ringed_planet": "🪐",

2028 "receipt": "🧾",

2029 "record_button": "⏺",

2030 "recycling_symbol": "♻",

2031 "red_apple": "🍎",

2032 "red_circle": "🔴",

2033 "red_envelope": "🧧",

2034 "red_hair": "🦰",

2035 "red-haired_man": "👨\u200d🦰",

2036 "red-haired_woman": "👩\u200d🦰",

2037 "red_heart": "❤",

2038 "red_paper_lantern": "🏮",

2039 "red_square": "🟥",

2040 "red_triangle_pointed_down": "🔻",

2041 "red_triangle_pointed_up": "🔺",

2042 "registered": "®",

2043 "relieved_face": "😌",

2044 "reminder_ribbon": "🎗",

2045 "repeat_button": "🔁",

2046 "repeat_single_button": "🔂",

2047 "rescue_worker’s_helmet": "⛑",

2048 "restroom": "🚻",

2049 "reverse_button": "◀",

2050 "revolving_hearts": "💞",

2051 "rhinoceros": "🦏",

2052 "ribbon": "🎀",

2053 "rice_ball": "🍙",

2054 "rice_cracker": "🍘",

2055 "right-facing_fist": "🤜",

2056 "right-facing_fist_dark_skin_tone": "🤜🏿",

2057 "right-facing_fist_light_skin_tone": "🤜🏻",

2058 "right-facing_fist_medium-dark_skin_tone": "🤜🏾",

2059 "right-facing_fist_medium-light_skin_tone": "🤜🏼",

2060 "right-facing_fist_medium_skin_tone": "🤜🏽",

2061 "right_anger_bubble": "🗯",

2062 "right_arrow": "➡",

2063 "right_arrow_curving_down": "⤵",

2064 "right_arrow_curving_left": "↩",

2065 "right_arrow_curving_up": "⤴",

2066 "ring": "💍",

2067 "roasted_sweet_potato": "🍠",

2068 "robot_face": "🤖",

2069 "rocket": "🚀",

2070 "roll_of_paper": "🧻",

2071 "rolled-up_newspaper": "🗞",

2072 "roller_coaster": "🎢",

2073 "rolling_on_the_floor_laughing": "🤣",

2074 "rooster": "🐓",

2075 "rose": "🌹",

2076 "rosette": "🏵",

2077 "round_pushpin": "📍",

2078 "rugby_football": "🏉",

2079 "running_shirt": "🎽",

2080 "running_shoe": "👟",

2081 "sad_but_relieved_face": "😥",

2082 "safety_pin": "🧷",

2083 "safety_vest": "🦺",

2084 "salt": "🧂",

2085 "sailboat": "⛵",

2086 "sake": "🍶",

2087 "sandwich": "🥪",

2088 "sari": "🥻",

2089 "satellite": "📡",

2090 "satellite_antenna": "📡",

2091 "sauropod": "🦕",

2092 "saxophone": "🎷",

2093 "scarf": "🧣",

2094 "school": "🏫",

2095 "school_backpack": "🎒",

2096 "scissors": "✂",

2097 "scorpion": "🦂",

2098 "scroll": "📜",

2099 "seat": "💺",

2100 "see-no-evil_monkey": "🙈",

2101 "seedling": "🌱",

2102 "selfie": "🤳",

2103 "selfie_dark_skin_tone": "🤳🏿",

2104 "selfie_light_skin_tone": "🤳🏻",

2105 "selfie_medium-dark_skin_tone": "🤳🏾",

2106 "selfie_medium-light_skin_tone": "🤳🏼",

2107 "selfie_medium_skin_tone": "🤳🏽",

2108 "service_dog": "🐕\u200d🦺",

2109 "seven-thirty": "🕢",

2110 "seven_o’clock": "🕖",

2111 "shallow_pan_of_food": "🥘",

2112 "shamrock": "☘",

2113 "shark": "🦈",

2114 "shaved_ice": "🍧",

2115 "sheaf_of_rice": "🌾",

2116 "shield": "🛡",

2117 "shinto_shrine": "⛩",

2118 "ship": "🚢",

2119 "shooting_star": "🌠",

2120 "shopping_bags": "🛍",

2121 "shopping_cart": "🛒",

2122 "shortcake": "🍰",

2123 "shorts": "🩳",

2124 "shower": "🚿",

2125 "shrimp": "🦐",

2126 "shuffle_tracks_button": "🔀",

2127 "shushing_face": "🤫",

2128 "sign_of_the_horns": "🤘",

2129 "sign_of_the_horns_dark_skin_tone": "🤘🏿",

2130 "sign_of_the_horns_light_skin_tone": "🤘🏻",

2131 "sign_of_the_horns_medium-dark_skin_tone": "🤘🏾",

2132 "sign_of_the_horns_medium-light_skin_tone": "🤘🏼",

2133 "sign_of_the_horns_medium_skin_tone": "🤘🏽",

2134 "six-thirty": "🕡",

2135 "six_o’clock": "🕕",

2136 "skateboard": "🛹",

2137 "skier": "⛷",

2138 "skis": "🎿",

2139 "skull": "💀",

2140 "skull_and_crossbones": "☠",

2141 "skunk": "🦨",

2142 "sled": "🛷",

2143 "sleeping_face": "😴",

2144 "sleepy_face": "😪",

2145 "slightly_frowning_face": "🙁",

2146 "slightly_smiling_face": "🙂",

2147 "slot_machine": "🎰",

2148 "sloth": "🦥",

2149 "small_airplane": "🛩",

2150 "small_blue_diamond": "🔹",

2151 "small_orange_diamond": "🔸",

2152 "smiling_cat_face_with_heart-eyes": "😻",

2153 "smiling_face": "☺",

2154 "smiling_face_with_halo": "😇",

2155 "smiling_face_with_3_hearts": "🥰",

2156 "smiling_face_with_heart-eyes": "😍",

2157 "smiling_face_with_horns": "😈",

2158 "smiling_face_with_smiling_eyes": "😊",

2159 "smiling_face_with_sunglasses": "😎",

2160 "smirking_face": "😏",

2161 "snail": "🐌",

2162 "snake": "🐍",

2163 "sneezing_face": "🤧",

2164 "snow-capped_mountain": "🏔",

2165 "snowboarder": "🏂",

2166 "snowboarder_dark_skin_tone": "🏂🏿",

2167 "snowboarder_light_skin_tone": "🏂🏻",

2168 "snowboarder_medium-dark_skin_tone": "🏂🏾",

2169 "snowboarder_medium-light_skin_tone": "🏂🏼",

2170 "snowboarder_medium_skin_tone": "🏂🏽",

2171 "snowflake": "❄",

2172 "snowman": "☃",

2173 "snowman_without_snow": "⛄",

2174 "soap": "🧼",

2175 "soccer_ball": "⚽",

2176 "socks": "🧦",

2177 "softball": "🥎",

2178 "soft_ice_cream": "🍦",

2179 "spade_suit": "♠",

2180 "spaghetti": "🍝",

2181 "sparkle": "❇",

2182 "sparkler": "🎇",

2183 "sparkles": "✨",

2184 "sparkling_heart": "💖",

2185 "speak-no-evil_monkey": "🙊",

2186 "speaker_high_volume": "🔊",

2187 "speaker_low_volume": "🔈",

2188 "speaker_medium_volume": "🔉",

2189 "speaking_head": "🗣",

2190 "speech_balloon": "💬",

2191 "speedboat": "🚤",

2192 "spider": "🕷",

2193 "spider_web": "🕸",

2194 "spiral_calendar": "🗓",

2195 "spiral_notepad": "🗒",

2196 "spiral_shell": "🐚",

2197 "spoon": "🥄",

2198 "sponge": "🧽",

2199 "sport_utility_vehicle": "🚙",

2200 "sports_medal": "🏅",

2201 "spouting_whale": "🐳",

2202 "squid": "🦑",

2203 "squinting_face_with_tongue": "😝",

2204 "stadium": "🏟",

2205 "star-struck": "🤩",

2206 "star_and_crescent": "☪",

2207 "star_of_david": "✡",

2208 "station": "🚉",

2209 "steaming_bowl": "🍜",

2210 "stethoscope": "🩺",

2211 "stop_button": "⏹",

2212 "stop_sign": "🛑",

2213 "stopwatch": "⏱",

2214 "straight_ruler": "📏",

2215 "strawberry": "🍓",

2216 "studio_microphone": "🎙",

2217 "stuffed_flatbread": "🥙",

2218 "sun": "☀",

2219 "sun_behind_cloud": "⛅",

2220 "sun_behind_large_cloud": "🌥",

2221 "sun_behind_rain_cloud": "🌦",

2222 "sun_behind_small_cloud": "🌤",

2223 "sun_with_face": "🌞",

2224 "sunflower": "🌻",

2225 "sunglasses": "😎",

2226 "sunrise": "🌅",

2227 "sunrise_over_mountains": "🌄",

2228 "sunset": "🌇",

2229 "superhero": "🦸",

2230 "supervillain": "🦹",

2231 "sushi": "🍣",

2232 "suspension_railway": "🚟",

2233 "swan": "🦢",

2234 "sweat_droplets": "💦",

2235 "synagogue": "🕍",

2236 "syringe": "💉",

2237 "t-shirt": "👕",

2238 "taco": "🌮",

2239 "takeout_box": "🥡",

2240 "tanabata_tree": "🎋",

2241 "tangerine": "🍊",

2242 "taxi": "🚕",

2243 "teacup_without_handle": "🍵",

2244 "tear-off_calendar": "📆",

2245 "teddy_bear": "🧸",

2246 "telephone": "☎",

2247 "telephone_receiver": "📞",

2248 "telescope": "🔭",

2249 "television": "📺",

2250 "ten-thirty": "🕥",

2251 "ten_o’clock": "🕙",

2252 "tennis": "🎾",

2253 "tent": "⛺",

2254 "test_tube": "🧪",

2255 "thermometer": "🌡",

2256 "thinking_face": "🤔",

2257 "thought_balloon": "💭",

2258 "thread": "🧵",

2259 "three-thirty": "🕞",

2260 "three_o’clock": "🕒",

2261 "thumbs_down": "👎",

2262 "thumbs_down_dark_skin_tone": "👎🏿",

2263 "thumbs_down_light_skin_tone": "👎🏻",

2264 "thumbs_down_medium-dark_skin_tone": "👎🏾",

2265 "thumbs_down_medium-light_skin_tone": "👎🏼",

2266 "thumbs_down_medium_skin_tone": "👎🏽",

2267 "thumbs_up": "👍",

2268 "thumbs_up_dark_skin_tone": "👍🏿",

2269 "thumbs_up_light_skin_tone": "👍🏻",

2270 "thumbs_up_medium-dark_skin_tone": "👍🏾",

2271 "thumbs_up_medium-light_skin_tone": "👍🏼",

2272 "thumbs_up_medium_skin_tone": "👍🏽",

2273 "ticket": "🎫",

2274 "tiger": "🐯",

2275 "tiger_face": "🐯",

2276 "timer_clock": "⏲",

2277 "tired_face": "😫",

2278 "toolbox": "🧰",

2279 "toilet": "🚽",

2280 "tomato": "🍅",

2281 "tongue": "👅",

2282 "tooth": "🦷",

2283 "top_hat": "🎩",

2284 "tornado": "🌪",

2285 "trackball": "🖲",

2286 "tractor": "🚜",

2287 "trade_mark": "™",

2288 "train": "🚋",

2289 "tram": "🚊",

2290 "tram_car": "🚋",

2291 "triangular_flag": "🚩",

2292 "triangular_ruler": "📐",

2293 "trident_emblem": "🔱",

2294 "trolleybus": "🚎",

2295 "trophy": "🏆",

2296 "tropical_drink": "🍹",

2297 "tropical_fish": "🐠",

2298 "trumpet": "🎺",

2299 "tulip": "🌷",

2300 "tumbler_glass": "🥃",

2301 "turtle": "🐢",

2302 "twelve-thirty": "🕧",

2303 "twelve_o’clock": "🕛",

2304 "two-hump_camel": "🐫",

2305 "two-thirty": "🕝",

2306 "two_hearts": "💕",

2307 "two_men_holding_hands": "👬",

2308 "two_o’clock": "🕑",

2309 "two_women_holding_hands": "👭",

2310 "umbrella": "☂",

2311 "umbrella_on_ground": "⛱",

2312 "umbrella_with_rain_drops": "☔",

2313 "unamused_face": "😒",

2314 "unicorn_face": "🦄",

2315 "unlocked": "🔓",

2316 "up-down_arrow": "↕",

2317 "up-left_arrow": "↖",

2318 "up-right_arrow": "↗",

2319 "up_arrow": "⬆",

2320 "upside-down_face": "🙃",

2321 "upwards_button": "🔼",

2322 "vampire": "🧛",

2323 "vampire_dark_skin_tone": "🧛🏿",

2324 "vampire_light_skin_tone": "🧛🏻",

2325 "vampire_medium-dark_skin_tone": "🧛🏾",

2326 "vampire_medium-light_skin_tone": "🧛🏼",

2327 "vampire_medium_skin_tone": "🧛🏽",

2328 "vertical_traffic_light": "🚦",

2329 "vibration_mode": "📳",

2330 "victory_hand": "✌",

2331 "victory_hand_dark_skin_tone": "✌🏿",

2332 "victory_hand_light_skin_tone": "✌🏻",

2333 "victory_hand_medium-dark_skin_tone": "✌🏾",

2334 "victory_hand_medium-light_skin_tone": "✌🏼",

2335 "victory_hand_medium_skin_tone": "✌🏽",

2336 "video_camera": "📹",

2337 "video_game": "🎮",

2338 "videocassette": "📼",

2339 "violin": "🎻",

2340 "volcano": "🌋",

2341 "volleyball": "🏐",

2342 "vulcan_salute": "🖖",

2343 "vulcan_salute_dark_skin_tone": "🖖🏿",

2344 "vulcan_salute_light_skin_tone": "🖖🏻",

2345 "vulcan_salute_medium-dark_skin_tone": "🖖🏾",

2346 "vulcan_salute_medium-light_skin_tone": "🖖🏼",

2347 "vulcan_salute_medium_skin_tone": "🖖🏽",

2348 "waffle": "🧇",

2349 "waning_crescent_moon": "🌘",

2350 "waning_gibbous_moon": "🌖",

2351 "warning": "⚠",

2352 "wastebasket": "🗑",

2353 "watch": "⌚",

2354 "water_buffalo": "🐃",

2355 "water_closet": "🚾",

2356 "water_wave": "🌊",

2357 "watermelon": "🍉",

2358 "waving_hand": "👋",

2359 "waving_hand_dark_skin_tone": "👋🏿",

2360 "waving_hand_light_skin_tone": "👋🏻",

2361 "waving_hand_medium-dark_skin_tone": "👋🏾",

2362 "waving_hand_medium-light_skin_tone": "👋🏼",

2363 "waving_hand_medium_skin_tone": "👋🏽",

2364 "wavy_dash": "〰",

2365 "waxing_crescent_moon": "🌒",

2366 "waxing_gibbous_moon": "🌔",

2367 "weary_cat_face": "🙀",

2368 "weary_face": "😩",

2369 "wedding": "💒",

2370 "whale": "🐳",

2371 "wheel_of_dharma": "☸",

2372 "wheelchair_symbol": "♿",

2373 "white_circle": "⚪",

2374 "white_exclamation_mark": "❕",

2375 "white_flag": "🏳",

2376 "white_flower": "💮",

2377 "white_hair": "🦳",

2378 "white-haired_man": "👨\u200d🦳",

2379 "white-haired_woman": "👩\u200d🦳",

2380 "white_heart": "🤍",

2381 "white_heavy_check_mark": "✅",

2382 "white_large_square": "⬜",

2383 "white_medium-small_square": "◽",

2384 "white_medium_square": "◻",

2385 "white_medium_star": "⭐",

2386 "white_question_mark": "❔",

2387 "white_small_square": "▫",

2388 "white_square_button": "🔳",

2389 "wilted_flower": "🥀",

2390 "wind_chime": "🎐",

2391 "wind_face": "🌬",

2392 "wine_glass": "🍷",

2393 "winking_face": "😉",

2394 "winking_face_with_tongue": "😜",

2395 "wolf_face": "🐺",

2396 "woman": "👩",

2397 "woman_artist": "👩\u200d🎨",

2398 "woman_artist_dark_skin_tone": "👩🏿\u200d🎨",

2399 "woman_artist_light_skin_tone": "👩🏻\u200d🎨",

2400 "woman_artist_medium-dark_skin_tone": "👩🏾\u200d🎨",

2401 "woman_artist_medium-light_skin_tone": "👩🏼\u200d🎨",

2402 "woman_artist_medium_skin_tone": "👩🏽\u200d🎨",

2403 "woman_astronaut": "👩\u200d🚀",

2404 "woman_astronaut_dark_skin_tone": "👩🏿\u200d🚀",

2405 "woman_astronaut_light_skin_tone": "👩🏻\u200d🚀",

2406 "woman_astronaut_medium-dark_skin_tone": "👩🏾\u200d🚀",

2407 "woman_astronaut_medium-light_skin_tone": "👩🏼\u200d🚀",

2408 "woman_astronaut_medium_skin_tone": "👩🏽\u200d🚀",

2409 "woman_biking": "🚴\u200d♀️",

2410 "woman_biking_dark_skin_tone": "🚴🏿\u200d♀️",

2411 "woman_biking_light_skin_tone": "🚴🏻\u200d♀️",

2412 "woman_biking_medium-dark_skin_tone": "🚴🏾\u200d♀️",

2413 "woman_biking_medium-light_skin_tone": "🚴🏼\u200d♀️",

2414 "woman_biking_medium_skin_tone": "🚴🏽\u200d♀️",

2415 "woman_bouncing_ball": "⛹️\u200d♀️",

2416 "woman_bouncing_ball_dark_skin_tone": "⛹🏿\u200d♀️",

2417 "woman_bouncing_ball_light_skin_tone": "⛹🏻\u200d♀️",

2418 "woman_bouncing_ball_medium-dark_skin_tone": "⛹🏾\u200d♀️",

2419 "woman_bouncing_ball_medium-light_skin_tone": "⛹🏼\u200d♀️",

2420 "woman_bouncing_ball_medium_skin_tone": "⛹🏽\u200d♀️",

2421 "woman_bowing": "🙇\u200d♀️",

2422 "woman_bowing_dark_skin_tone": "🙇🏿\u200d♀️",

2423 "woman_bowing_light_skin_tone": "🙇🏻\u200d♀️",

2424 "woman_bowing_medium-dark_skin_tone": "🙇🏾\u200d♀️",

2425 "woman_bowing_medium-light_skin_tone": "🙇🏼\u200d♀️",

2426 "woman_bowing_medium_skin_tone": "🙇🏽\u200d♀️",

2427 "woman_cartwheeling": "🤸\u200d♀️",

2428 "woman_cartwheeling_dark_skin_tone": "🤸🏿\u200d♀️",

2429 "woman_cartwheeling_light_skin_tone": "🤸🏻\u200d♀️",

2430 "woman_cartwheeling_medium-dark_skin_tone": "🤸🏾\u200d♀️",

2431 "woman_cartwheeling_medium-light_skin_tone": "🤸🏼\u200d♀️",

2432 "woman_cartwheeling_medium_skin_tone": "🤸🏽\u200d♀️",

2433 "woman_climbing": "🧗\u200d♀️",

2434 "woman_climbing_dark_skin_tone": "🧗🏿\u200d♀️",

2435 "woman_climbing_light_skin_tone": "🧗🏻\u200d♀️",

2436 "woman_climbing_medium-dark_skin_tone": "🧗🏾\u200d♀️",

2437 "woman_climbing_medium-light_skin_tone": "🧗🏼\u200d♀️",

2438 "woman_climbing_medium_skin_tone": "🧗🏽\u200d♀️",

2439 "woman_construction_worker": "👷\u200d♀️",

2440 "woman_construction_worker_dark_skin_tone": "👷🏿\u200d♀️",

2441 "woman_construction_worker_light_skin_tone": "👷🏻\u200d♀️",

2442 "woman_construction_worker_medium-dark_skin_tone": "👷🏾\u200d♀️",

2443 "woman_construction_worker_medium-light_skin_tone": "👷🏼\u200d♀️",

2444 "woman_construction_worker_medium_skin_tone": "👷🏽\u200d♀️",

2445 "woman_cook": "👩\u200d🍳",

2446 "woman_cook_dark_skin_tone": "👩🏿\u200d🍳",

2447 "woman_cook_light_skin_tone": "👩🏻\u200d🍳",

2448 "woman_cook_medium-dark_skin_tone": "👩🏾\u200d🍳",

2449 "woman_cook_medium-light_skin_tone": "👩🏼\u200d🍳",

2450 "woman_cook_medium_skin_tone": "👩🏽\u200d🍳",

2451 "woman_dancing": "💃",

2452 "woman_dancing_dark_skin_tone": "💃🏿",

2453 "woman_dancing_light_skin_tone": "💃🏻",

2454 "woman_dancing_medium-dark_skin_tone": "💃🏾",

2455 "woman_dancing_medium-light_skin_tone": "💃🏼",

2456 "woman_dancing_medium_skin_tone": "💃🏽",

2457 "woman_dark_skin_tone": "👩🏿",

2458 "woman_detective": "🕵️\u200d♀️",

2459 "woman_detective_dark_skin_tone": "🕵🏿\u200d♀️",

2460 "woman_detective_light_skin_tone": "🕵🏻\u200d♀️",

2461 "woman_detective_medium-dark_skin_tone": "🕵🏾\u200d♀️",

2462 "woman_detective_medium-light_skin_tone": "🕵🏼\u200d♀️",

2463 "woman_detective_medium_skin_tone": "🕵🏽\u200d♀️",

2464 "woman_elf": "🧝\u200d♀️",

2465 "woman_elf_dark_skin_tone": "🧝🏿\u200d♀️",

2466 "woman_elf_light_skin_tone": "🧝🏻\u200d♀️",

2467 "woman_elf_medium-dark_skin_tone": "🧝🏾\u200d♀️",

2468 "woman_elf_medium-light_skin_tone": "🧝🏼\u200d♀️",

2469 "woman_elf_medium_skin_tone": "🧝🏽\u200d♀️",

2470 "woman_facepalming": "🤦\u200d♀️",

2471 "woman_facepalming_dark_skin_tone": "🤦🏿\u200d♀️",

2472 "woman_facepalming_light_skin_tone": "🤦🏻\u200d♀️",

2473 "woman_facepalming_medium-dark_skin_tone": "🤦🏾\u200d♀️",

2474 "woman_facepalming_medium-light_skin_tone": "🤦🏼\u200d♀️",

2475 "woman_facepalming_medium_skin_tone": "🤦🏽\u200d♀️",

2476 "woman_factory_worker": "👩\u200d🏭",

2477 "woman_factory_worker_dark_skin_tone": "👩🏿\u200d🏭",

2478 "woman_factory_worker_light_skin_tone": "👩🏻\u200d🏭",

2479 "woman_factory_worker_medium-dark_skin_tone": "👩🏾\u200d🏭",

2480 "woman_factory_worker_medium-light_skin_tone": "👩🏼\u200d🏭",

2481 "woman_factory_worker_medium_skin_tone": "👩🏽\u200d🏭",

2482 "woman_fairy": "🧚\u200d♀️",

2483 "woman_fairy_dark_skin_tone": "🧚🏿\u200d♀️",

2484 "woman_fairy_light_skin_tone": "🧚🏻\u200d♀️",

2485 "woman_fairy_medium-dark_skin_tone": "🧚🏾\u200d♀️",

2486 "woman_fairy_medium-light_skin_tone": "🧚🏼\u200d♀️",

2487 "woman_fairy_medium_skin_tone": "🧚🏽\u200d♀️",

2488 "woman_farmer": "👩\u200d🌾",

2489 "woman_farmer_dark_skin_tone": "👩🏿\u200d🌾",

2490 "woman_farmer_light_skin_tone": "👩🏻\u200d🌾",

2491 "woman_farmer_medium-dark_skin_tone": "👩🏾\u200d🌾",

2492 "woman_farmer_medium-light_skin_tone": "👩🏼\u200d🌾",

2493 "woman_farmer_medium_skin_tone": "👩🏽\u200d🌾",

2494 "woman_firefighter": "👩\u200d🚒",

2495 "woman_firefighter_dark_skin_tone": "👩🏿\u200d🚒",

2496 "woman_firefighter_light_skin_tone": "👩🏻\u200d🚒",

2497 "woman_firefighter_medium-dark_skin_tone": "👩🏾\u200d🚒",

2498 "woman_firefighter_medium-light_skin_tone": "👩🏼\u200d🚒",

2499 "woman_firefighter_medium_skin_tone": "👩🏽\u200d🚒",

2500 "woman_frowning": "🙍\u200d♀️",

2501 "woman_frowning_dark_skin_tone": "🙍🏿\u200d♀️",

2502 "woman_frowning_light_skin_tone": "🙍🏻\u200d♀️",

2503 "woman_frowning_medium-dark_skin_tone": "🙍🏾\u200d♀️",

2504 "woman_frowning_medium-light_skin_tone": "🙍🏼\u200d♀️",

2505 "woman_frowning_medium_skin_tone": "🙍🏽\u200d♀️",

2506 "woman_genie": "🧞\u200d♀️",

2507 "woman_gesturing_no": "🙅\u200d♀️",

2508 "woman_gesturing_no_dark_skin_tone": "🙅🏿\u200d♀️",

2509 "woman_gesturing_no_light_skin_tone": "🙅🏻\u200d♀️",

2510 "woman_gesturing_no_medium-dark_skin_tone": "🙅🏾\u200d♀️",

2511 "woman_gesturing_no_medium-light_skin_tone": "🙅🏼\u200d♀️",

2512 "woman_gesturing_no_medium_skin_tone": "🙅🏽\u200d♀️",

2513 "woman_gesturing_ok": "🙆\u200d♀️",

2514 "woman_gesturing_ok_dark_skin_tone": "🙆🏿\u200d♀️",

2515 "woman_gesturing_ok_light_skin_tone": "🙆🏻\u200d♀️",

2516 "woman_gesturing_ok_medium-dark_skin_tone": "🙆🏾\u200d♀️",

2517 "woman_gesturing_ok_medium-light_skin_tone": "🙆🏼\u200d♀️",

2518 "woman_gesturing_ok_medium_skin_tone": "🙆🏽\u200d♀️",

2519 "woman_getting_haircut": "💇\u200d♀️",

2520 "woman_getting_haircut_dark_skin_tone": "💇🏿\u200d♀️",

2521 "woman_getting_haircut_light_skin_tone": "💇🏻\u200d♀️",

2522 "woman_getting_haircut_medium-dark_skin_tone": "💇🏾\u200d♀️",

2523 "woman_getting_haircut_medium-light_skin_tone": "💇🏼\u200d♀️",

2524 "woman_getting_haircut_medium_skin_tone": "💇🏽\u200d♀️",

2525 "woman_getting_massage": "💆\u200d♀️",

2526 "woman_getting_massage_dark_skin_tone": "💆🏿\u200d♀️",

2527 "woman_getting_massage_light_skin_tone": "💆🏻\u200d♀️",

2528 "woman_getting_massage_medium-dark_skin_tone": "💆🏾\u200d♀️",

2529 "woman_getting_massage_medium-light_skin_tone": "💆🏼\u200d♀️",

2530 "woman_getting_massage_medium_skin_tone": "💆🏽\u200d♀️",

2531 "woman_golfing": "🏌️\u200d♀️",

2532 "woman_golfing_dark_skin_tone": "🏌🏿\u200d♀️",

2533 "woman_golfing_light_skin_tone": "🏌🏻\u200d♀️",

2534 "woman_golfing_medium-dark_skin_tone": "🏌🏾\u200d♀️",

2535 "woman_golfing_medium-light_skin_tone": "🏌🏼\u200d♀️",

2536 "woman_golfing_medium_skin_tone": "🏌🏽\u200d♀️",

2537 "woman_guard": "💂\u200d♀️",

2538 "woman_guard_dark_skin_tone": "💂🏿\u200d♀️",

2539 "woman_guard_light_skin_tone": "💂🏻\u200d♀️",

2540 "woman_guard_medium-dark_skin_tone": "💂🏾\u200d♀️",

2541 "woman_guard_medium-light_skin_tone": "💂🏼\u200d♀️",

2542 "woman_guard_medium_skin_tone": "💂🏽\u200d♀️",

2543 "woman_health_worker": "👩\u200d⚕️",

2544 "woman_health_worker_dark_skin_tone": "👩🏿\u200d⚕️",

2545 "woman_health_worker_light_skin_tone": "👩🏻\u200d⚕️",

2546 "woman_health_worker_medium-dark_skin_tone": "👩🏾\u200d⚕️",

2547 "woman_health_worker_medium-light_skin_tone": "👩🏼\u200d⚕️",

2548 "woman_health_worker_medium_skin_tone": "👩🏽\u200d⚕️",

2549 "woman_in_lotus_position": "🧘\u200d♀️",

2550 "woman_in_lotus_position_dark_skin_tone": "🧘🏿\u200d♀️",

2551 "woman_in_lotus_position_light_skin_tone": "🧘🏻\u200d♀️",

2552 "woman_in_lotus_position_medium-dark_skin_tone": "🧘🏾\u200d♀️",

2553 "woman_in_lotus_position_medium-light_skin_tone": "🧘🏼\u200d♀️",

2554 "woman_in_lotus_position_medium_skin_tone": "🧘🏽\u200d♀️",

2555 "woman_in_manual_wheelchair": "👩\u200d🦽",

2556 "woman_in_motorized_wheelchair": "👩\u200d🦼",

2557 "woman_in_steamy_room": "🧖\u200d♀️",

2558 "woman_in_steamy_room_dark_skin_tone": "🧖🏿\u200d♀️",

2559 "woman_in_steamy_room_light_skin_tone": "🧖🏻\u200d♀️",

2560 "woman_in_steamy_room_medium-dark_skin_tone": "🧖🏾\u200d♀️",

2561 "woman_in_steamy_room_medium-light_skin_tone": "🧖🏼\u200d♀️",

2562 "woman_in_steamy_room_medium_skin_tone": "🧖🏽\u200d♀️",

2563 "woman_judge": "👩\u200d⚖️",

2564 "woman_judge_dark_skin_tone": "👩🏿\u200d⚖️",

2565 "woman_judge_light_skin_tone": "👩🏻\u200d⚖️",

2566 "woman_judge_medium-dark_skin_tone": "👩🏾\u200d⚖️",

2567 "woman_judge_medium-light_skin_tone": "👩🏼\u200d⚖️",

2568 "woman_judge_medium_skin_tone": "👩🏽\u200d⚖️",

2569 "woman_juggling": "🤹\u200d♀️",

2570 "woman_juggling_dark_skin_tone": "🤹🏿\u200d♀️",

2571 "woman_juggling_light_skin_tone": "🤹🏻\u200d♀️",

2572 "woman_juggling_medium-dark_skin_tone": "🤹🏾\u200d♀️",

2573 "woman_juggling_medium-light_skin_tone": "🤹🏼\u200d♀️",

2574 "woman_juggling_medium_skin_tone": "🤹🏽\u200d♀️",

2575 "woman_lifting_weights": "🏋️\u200d♀️",

2576 "woman_lifting_weights_dark_skin_tone": "🏋🏿\u200d♀️",

2577 "woman_lifting_weights_light_skin_tone": "🏋🏻\u200d♀️",

2578 "woman_lifting_weights_medium-dark_skin_tone": "🏋🏾\u200d♀️",

2579 "woman_lifting_weights_medium-light_skin_tone": "🏋🏼\u200d♀️",

2580 "woman_lifting_weights_medium_skin_tone": "🏋🏽\u200d♀️",

2581 "woman_light_skin_tone": "👩🏻",

2582 "woman_mage": "🧙\u200d♀️",

2583 "woman_mage_dark_skin_tone": "🧙🏿\u200d♀️",

2584 "woman_mage_light_skin_tone": "🧙🏻\u200d♀️",

2585 "woman_mage_medium-dark_skin_tone": "🧙🏾\u200d♀️",

2586 "woman_mage_medium-light_skin_tone": "🧙🏼\u200d♀️",

2587 "woman_mage_medium_skin_tone": "🧙🏽\u200d♀️",

2588 "woman_mechanic": "👩\u200d🔧",

2589 "woman_mechanic_dark_skin_tone": "👩🏿\u200d🔧",

2590 "woman_mechanic_light_skin_tone": "👩🏻\u200d🔧",

2591 "woman_mechanic_medium-dark_skin_tone": "👩🏾\u200d🔧",

2592 "woman_mechanic_medium-light_skin_tone": "👩🏼\u200d🔧",

2593 "woman_mechanic_medium_skin_tone": "👩🏽\u200d🔧",

2594 "woman_medium-dark_skin_tone": "👩🏾",

2595 "woman_medium-light_skin_tone": "👩🏼",

2596 "woman_medium_skin_tone": "👩🏽",

2597 "woman_mountain_biking": "🚵\u200d♀️",

2598 "woman_mountain_biking_dark_skin_tone": "🚵🏿\u200d♀️",

2599 "woman_mountain_biking_light_skin_tone": "🚵🏻\u200d♀️",

2600 "woman_mountain_biking_medium-dark_skin_tone": "🚵🏾\u200d♀️",

2601 "woman_mountain_biking_medium-light_skin_tone": "🚵🏼\u200d♀️",

2602 "woman_mountain_biking_medium_skin_tone": "🚵🏽\u200d♀️",

2603 "woman_office_worker": "👩\u200d💼",

2604 "woman_office_worker_dark_skin_tone": "👩🏿\u200d💼",

2605 "woman_office_worker_light_skin_tone": "👩🏻\u200d💼",

2606 "woman_office_worker_medium-dark_skin_tone": "👩🏾\u200d💼",

2607 "woman_office_worker_medium-light_skin_tone": "👩🏼\u200d💼",

2608 "woman_office_worker_medium_skin_tone": "👩🏽\u200d💼",

2609 "woman_pilot": "👩\u200d✈️",

2610 "woman_pilot_dark_skin_tone": "👩🏿\u200d✈️",

2611 "woman_pilot_light_skin_tone": "👩🏻\u200d✈️",

2612 "woman_pilot_medium-dark_skin_tone": "👩🏾\u200d✈️",

2613 "woman_pilot_medium-light_skin_tone": "👩🏼\u200d✈️",

2614 "woman_pilot_medium_skin_tone": "👩🏽\u200d✈️",

2615 "woman_playing_handball": "🤾\u200d♀️",

2616 "woman_playing_handball_dark_skin_tone": "🤾🏿\u200d♀️",

2617 "woman_playing_handball_light_skin_tone": "🤾🏻\u200d♀️",

2618 "woman_playing_handball_medium-dark_skin_tone": "🤾🏾\u200d♀️",

2619 "woman_playing_handball_medium-light_skin_tone": "🤾🏼\u200d♀️",

2620 "woman_playing_handball_medium_skin_tone": "🤾🏽\u200d♀️",

2621 "woman_playing_water_polo": "🤽\u200d♀️",

2622 "woman_playing_water_polo_dark_skin_tone": "🤽🏿\u200d♀️",

2623 "woman_playing_water_polo_light_skin_tone": "🤽🏻\u200d♀️",

2624 "woman_playing_water_polo_medium-dark_skin_tone": "🤽🏾\u200d♀️",

2625 "woman_playing_water_polo_medium-light_skin_tone": "🤽🏼\u200d♀️",

2626 "woman_playing_water_polo_medium_skin_tone": "🤽🏽\u200d♀️",

2627 "woman_police_officer": "👮\u200d♀️",

2628 "woman_police_officer_dark_skin_tone": "👮🏿\u200d♀️",

2629 "woman_police_officer_light_skin_tone": "👮🏻\u200d♀️",

2630 "woman_police_officer_medium-dark_skin_tone": "👮🏾\u200d♀️",

2631 "woman_police_officer_medium-light_skin_tone": "👮🏼\u200d♀️",

2632 "woman_police_officer_medium_skin_tone": "👮🏽\u200d♀️",

2633 "woman_pouting": "🙎\u200d♀️",

2634 "woman_pouting_dark_skin_tone": "🙎🏿\u200d♀️",

2635 "woman_pouting_light_skin_tone": "🙎🏻\u200d♀️",

2636 "woman_pouting_medium-dark_skin_tone": "🙎🏾\u200d♀️",

2637 "woman_pouting_medium-light_skin_tone": "🙎🏼\u200d♀️",

2638 "woman_pouting_medium_skin_tone": "🙎🏽\u200d♀️",

2639 "woman_raising_hand": "🙋\u200d♀️",

2640 "woman_raising_hand_dark_skin_tone": "🙋🏿\u200d♀️",

2641 "woman_raising_hand_light_skin_tone": "🙋🏻\u200d♀️",

2642 "woman_raising_hand_medium-dark_skin_tone": "🙋🏾\u200d♀️",

2643 "woman_raising_hand_medium-light_skin_tone": "🙋🏼\u200d♀️",

2644 "woman_raising_hand_medium_skin_tone": "🙋🏽\u200d♀️",

2645 "woman_rowing_boat": "🚣\u200d♀️",

2646 "woman_rowing_boat_dark_skin_tone": "🚣🏿\u200d♀️",

2647 "woman_rowing_boat_light_skin_tone": "🚣🏻\u200d♀️",

2648 "woman_rowing_boat_medium-dark_skin_tone": "🚣🏾\u200d♀️",

2649 "woman_rowing_boat_medium-light_skin_tone": "🚣🏼\u200d♀️",

2650 "woman_rowing_boat_medium_skin_tone": "🚣🏽\u200d♀️",

2651 "woman_running": "🏃\u200d♀️",

2652 "woman_running_dark_skin_tone": "🏃🏿\u200d♀️",

2653 "woman_running_light_skin_tone": "🏃🏻\u200d♀️",

2654 "woman_running_medium-dark_skin_tone": "🏃🏾\u200d♀️",

2655 "woman_running_medium-light_skin_tone": "🏃🏼\u200d♀️",

2656 "woman_running_medium_skin_tone": "🏃🏽\u200d♀️",

2657 "woman_scientist": "👩\u200d🔬",

2658 "woman_scientist_dark_skin_tone": "👩🏿\u200d🔬",

2659 "woman_scientist_light_skin_tone": "👩🏻\u200d🔬",

2660 "woman_scientist_medium-dark_skin_tone": "👩🏾\u200d🔬",

2661 "woman_scientist_medium-light_skin_tone": "👩🏼\u200d🔬",

2662 "woman_scientist_medium_skin_tone": "👩🏽\u200d🔬",

2663 "woman_shrugging": "🤷\u200d♀️",

2664 "woman_shrugging_dark_skin_tone": "🤷🏿\u200d♀️",

2665 "woman_shrugging_light_skin_tone": "🤷🏻\u200d♀️",

2666 "woman_shrugging_medium-dark_skin_tone": "🤷🏾\u200d♀️",

2667 "woman_shrugging_medium-light_skin_tone": "🤷🏼\u200d♀️",

2668 "woman_shrugging_medium_skin_tone": "🤷🏽\u200d♀️",

2669 "woman_singer": "👩\u200d🎤",

2670 "woman_singer_dark_skin_tone": "👩🏿\u200d🎤",

2671 "woman_singer_light_skin_tone": "👩🏻\u200d🎤",

2672 "woman_singer_medium-dark_skin_tone": "👩🏾\u200d🎤",

2673 "woman_singer_medium-light_skin_tone": "👩🏼\u200d🎤",

2674 "woman_singer_medium_skin_tone": "👩🏽\u200d🎤",

2675 "woman_student": "👩\u200d🎓",

2676 "woman_student_dark_skin_tone": "👩🏿\u200d🎓",

2677 "woman_student_light_skin_tone": "👩🏻\u200d🎓",

2678 "woman_student_medium-dark_skin_tone": "👩🏾\u200d🎓",

2679 "woman_student_medium-light_skin_tone": "👩🏼\u200d🎓",

2680 "woman_student_medium_skin_tone": "👩🏽\u200d🎓",

2681 "woman_surfing": "🏄\u200d♀️",

2682 "woman_surfing_dark_skin_tone": "🏄🏿\u200d♀️",

2683 "woman_surfing_light_skin_tone": "🏄🏻\u200d♀️",

2684 "woman_surfing_medium-dark_skin_tone": "🏄🏾\u200d♀️",

2685 "woman_surfing_medium-light_skin_tone": "🏄🏼\u200d♀️",

2686 "woman_surfing_medium_skin_tone": "🏄🏽\u200d♀️",

2687 "woman_swimming": "🏊\u200d♀️",

2688 "woman_swimming_dark_skin_tone": "🏊🏿\u200d♀️",

2689 "woman_swimming_light_skin_tone": "🏊🏻\u200d♀️",

2690 "woman_swimming_medium-dark_skin_tone": "🏊🏾\u200d♀️",

2691 "woman_swimming_medium-light_skin_tone": "🏊🏼\u200d♀️",

2692 "woman_swimming_medium_skin_tone": "🏊🏽\u200d♀️",

2693 "woman_teacher": "👩\u200d🏫",

2694 "woman_teacher_dark_skin_tone": "👩🏿\u200d🏫",

2695 "woman_teacher_light_skin_tone": "👩🏻\u200d🏫",

2696 "woman_teacher_medium-dark_skin_tone": "👩🏾\u200d🏫",

2697 "woman_teacher_medium-light_skin_tone": "👩🏼\u200d🏫",

2698 "woman_teacher_medium_skin_tone": "👩🏽\u200d🏫",

2699 "woman_technologist": "👩\u200d💻",

2700 "woman_technologist_dark_skin_tone": "👩🏿\u200d💻",

2701 "woman_technologist_light_skin_tone": "👩🏻\u200d💻",

2702 "woman_technologist_medium-dark_skin_tone": "👩🏾\u200d💻",

2703 "woman_technologist_medium-light_skin_tone": "👩🏼\u200d💻",

2704 "woman_technologist_medium_skin_tone": "👩🏽\u200d💻",

2705 "woman_tipping_hand": "💁\u200d♀️",

2706 "woman_tipping_hand_dark_skin_tone": "💁🏿\u200d♀️",

2707 "woman_tipping_hand_light_skin_tone": "💁🏻\u200d♀️",

2708 "woman_tipping_hand_medium-dark_skin_tone": "💁🏾\u200d♀️",

2709 "woman_tipping_hand_medium-light_skin_tone": "💁🏼\u200d♀️",

2710 "woman_tipping_hand_medium_skin_tone": "💁🏽\u200d♀️",

2711 "woman_vampire": "🧛\u200d♀️",

2712 "woman_vampire_dark_skin_tone": "🧛🏿\u200d♀️",

2713 "woman_vampire_light_skin_tone": "🧛🏻\u200d♀️",

2714 "woman_vampire_medium-dark_skin_tone": "🧛🏾\u200d♀️",

2715 "woman_vampire_medium-light_skin_tone": "🧛🏼\u200d♀️",

2716 "woman_vampire_medium_skin_tone": "🧛🏽\u200d♀️",

2717 "woman_walking": "🚶\u200d♀️",

2718 "woman_walking_dark_skin_tone": "🚶🏿\u200d♀️",

2719 "woman_walking_light_skin_tone": "🚶🏻\u200d♀️",

2720 "woman_walking_medium-dark_skin_tone": "🚶🏾\u200d♀️",

2721 "woman_walking_medium-light_skin_tone": "🚶🏼\u200d♀️",

2722 "woman_walking_medium_skin_tone": "🚶🏽\u200d♀️",

2723 "woman_wearing_turban": "👳\u200d♀️",

2724 "woman_wearing_turban_dark_skin_tone": "👳🏿\u200d♀️",

2725 "woman_wearing_turban_light_skin_tone": "👳🏻\u200d♀️",

2726 "woman_wearing_turban_medium-dark_skin_tone": "👳🏾\u200d♀️",

2727 "woman_wearing_turban_medium-light_skin_tone": "👳🏼\u200d♀️",

2728 "woman_wearing_turban_medium_skin_tone": "👳🏽\u200d♀️",

2729 "woman_with_headscarf": "🧕",

2730 "woman_with_headscarf_dark_skin_tone": "🧕🏿",

2731 "woman_with_headscarf_light_skin_tone": "🧕🏻",

2732 "woman_with_headscarf_medium-dark_skin_tone": "🧕🏾",

2733 "woman_with_headscarf_medium-light_skin_tone": "🧕🏼",

2734 "woman_with_headscarf_medium_skin_tone": "🧕🏽",

2735 "woman_with_probing_cane": "👩\u200d🦯",

2736 "woman_zombie": "🧟\u200d♀️",

2737 "woman’s_boot": "👢",

2738 "woman’s_clothes": "👚",

2739 "woman’s_hat": "👒",

2740 "woman’s_sandal": "👡",

2741 "women_with_bunny_ears": "👯\u200d♀️",

2742 "women_wrestling": "🤼\u200d♀️",

2743 "women’s_room": "🚺",

2744 "woozy_face": "🥴",

2745 "world_map": "🗺",

2746 "worried_face": "😟",

2747 "wrapped_gift": "🎁",

2748 "wrench": "🔧",

2749 "writing_hand": "✍",

2750 "writing_hand_dark_skin_tone": "✍🏿",

2751 "writing_hand_light_skin_tone": "✍🏻",

2752 "writing_hand_medium-dark_skin_tone": "✍🏾",

2753 "writing_hand_medium-light_skin_tone": "✍🏼",

2754 "writing_hand_medium_skin_tone": "✍🏽",

2755 "yarn": "🧶",

2756 "yawning_face": "🥱",

2757 "yellow_circle": "🟡",

2758 "yellow_heart": "💛",

2759 "yellow_square": "🟨",

2760 "yen_banknote": "💴",

2761 "yo-yo": "🪀",

2762 "yin_yang": "☯",

2763 "zany_face": "🤪",

2764 "zebra": "🦓",

2765 "zipper-mouth_face": "🤐",

2766 "zombie": "🧟",

2767 "zzz": "💤",

2768 "åland_islands": "🇦🇽",

2769 "keycap_asterisk": "*⃣",

2770 "keycap_digit_eight": "8⃣",

2771 "keycap_digit_five": "5⃣",

2772 "keycap_digit_four": "4⃣",

2773 "keycap_digit_nine": "9⃣",

2774 "keycap_digit_one": "1⃣",

2775 "keycap_digit_seven": "7⃣",

2776 "keycap_digit_six": "6⃣",

2777 "keycap_digit_three": "3⃣",

2778 "keycap_digit_two": "2⃣",

2779 "keycap_digit_zero": "0⃣",

2780 "keycap_number_sign": "#⃣",

2781 "light_skin_tone": "🏻",

2782 "medium_light_skin_tone": "🏼",

2783 "medium_skin_tone": "🏽",

2784 "medium_dark_skin_tone": "🏾",

2785 "dark_skin_tone": "🏿",

2786 "regional_indicator_symbol_letter_a": "🇦",

2787 "regional_indicator_symbol_letter_b": "🇧",

2788 "regional_indicator_symbol_letter_c": "🇨",

2789 "regional_indicator_symbol_letter_d": "🇩",

2790 "regional_indicator_symbol_letter_e": "🇪",

2791 "regional_indicator_symbol_letter_f": "🇫",

2792 "regional_indicator_symbol_letter_g": "🇬",

2793 "regional_indicator_symbol_letter_h": "🇭",

2794 "regional_indicator_symbol_letter_i": "🇮",

2795 "regional_indicator_symbol_letter_j": "🇯",

2796 "regional_indicator_symbol_letter_k": "🇰",

2797 "regional_indicator_symbol_letter_l": "🇱",

2798 "regional_indicator_symbol_letter_m": "🇲",

2799 "regional_indicator_symbol_letter_n": "🇳",

2800 "regional_indicator_symbol_letter_o": "🇴",

2801 "regional_indicator_symbol_letter_p": "🇵",

2802 "regional_indicator_symbol_letter_q": "🇶",

2803 "regional_indicator_symbol_letter_r": "🇷",

2804 "regional_indicator_symbol_letter_s": "🇸",

2805 "regional_indicator_symbol_letter_t": "🇹",

2806 "regional_indicator_symbol_letter_u": "🇺",

2807 "regional_indicator_symbol_letter_v": "🇻",

2808 "regional_indicator_symbol_letter_w": "🇼",

2809 "regional_indicator_symbol_letter_x": "🇽",

2810 "regional_indicator_symbol_letter_y": "🇾",

2811 "regional_indicator_symbol_letter_z": "🇿",

2812 "airplane_arriving": "🛬",

2813 "space_invader": "👾",

2814 "football": "🏈",

2815 "anger": "💢",

2816 "angry": "😠",

2817 "anguished": "😧",

2818 "signal_strength": "📶",

2819 "arrows_counterclockwise": "🔄",

2820 "arrow_heading_down": "⤵",

2821 "arrow_heading_up": "⤴",

2822 "art": "🎨",

2823 "astonished": "😲",

2824 "athletic_shoe": "👟",

2825 "atm": "🏧",

2826 "car": "🚗",

2827 "red_car": "🚗",

2828 "angel": "👼",

2829 "back": "🔙",

2830 "badminton_racquet_and_shuttlecock": "🏸",

2831 "dollar": "💵",

2832 "euro": "💶",

2833 "pound": "💷",

2834 "yen": "💴",

2835 "barber": "💈",

2836 "bath": "🛀",

2837 "bear": "🐻",

2838 "heartbeat": "💓",

2839 "beer": "🍺",

2840 "no_bell": "🔕",

2841 "bento": "🍱",

2842 "bike": "🚲",

2843 "bicyclist": "🚴",

2844 "8ball": "🎱",

2845 "biohazard_sign": "☣",

2846 "birthday": "🎂",

2847 "black_circle_for_record": "⏺",

2848 "clubs": "♣",

2849 "diamonds": "♦",

2850 "arrow_double_down": "⏬",

2851 "hearts": "♥",

2852 "rewind": "⏪",

2853 "black_left__pointing_double_triangle_with_vertical_bar": "⏮",

2854 "arrow_backward": "◀",

2855 "black_medium_small_square": "◾",

2856 "question": "❓",

2857 "fast_forward": "⏩",

2858 "black_right__pointing_double_triangle_with_vertical_bar": "⏭",

2859 "arrow_forward": "▶",

2860 "black_right__pointing_triangle_with_double_vertical_bar": "⏯",

2861 "arrow_right": "➡",

2862 "spades": "♠",

2863 "black_square_for_stop": "⏹",

2864 "sunny": "☀",

2865 "phone": "☎",

2866 "recycle": "♻",

2867 "arrow_double_up": "⏫",

2868 "busstop": "🚏",

2869 "date": "📅",

2870 "flags": "🎏",

2871 "cat2": "🐈",

2872 "joy_cat": "😹",

2873 "smirk_cat": "😼",

2874 "chart_with_downwards_trend": "📉",

2875 "chart_with_upwards_trend": "📈",

2876 "chart": "💹",

2877 "mega": "📣",

2878 "checkered_flag": "🏁",

2879 "accept": "🉑",

2880 "ideograph_advantage": "🉐",

2881 "congratulations": "㊗",

2882 "secret": "㊙",

2883 "m": "Ⓜ",

2884 "city_sunset": "🌆",

2885 "clapper": "🎬",

2886 "clap": "👏",

2887 "beers": "🍻",

2888 "clock830": "🕣",

2889 "clock8": "🕗",

2890 "clock1130": "🕦",

2891 "clock11": "🕚",

2892 "clock530": "🕠",

2893 "clock5": "🕔",

2894 "clock430": "🕟",

2895 "clock4": "🕓",

2896 "clock930": "🕤",

2897 "clock9": "🕘",

2898 "clock130": "🕜",

2899 "clock1": "🕐",

2900 "clock730": "🕢",

2901 "clock7": "🕖",

2902 "clock630": "🕡",

2903 "clock6": "🕕",

2904 "clock1030": "🕥",

2905 "clock10": "🕙",

2906 "clock330": "🕞",

2907 "clock3": "🕒",

2908 "clock1230": "🕧",

2909 "clock12": "🕛",

2910 "clock230": "🕝",

2911 "clock2": "🕑",

2912 "arrows_clockwise": "🔃",

2913 "repeat": "🔁",

2914 "repeat_one": "🔂",

2915 "closed_lock_with_key": "🔐",

2916 "mailbox_closed": "📪",

2917 "mailbox": "📫",

2918 "cloud_with_tornado": "🌪",

2919 "cocktail": "🍸",

2920 "boom": "💥",

2921 "compression": "🗜",

2922 "confounded": "😖",

2923 "confused": "😕",

2924 "rice": "🍚",

2925 "cow2": "🐄",

2926 "cricket_bat_and_ball": "🏏",

2927 "x": "❌",

2928 "cry": "😢",

2929 "curry": "🍛",

2930 "dagger_knife": "🗡",

2931 "dancer": "💃",

2932 "dark_sunglasses": "🕶",

2933 "dash": "💨",

2934 "truck": "🚚",

2935 "derelict_house_building": "🏚",

2936 "diamond_shape_with_a_dot_inside": "💠",

2937 "dart": "🎯",

2938 "disappointed_relieved": "😥",

2939 "disappointed": "😞",

2940 "do_not_litter": "🚯",

2941 "dog2": "🐕",

2942 "flipper": "🐬",

2943 "loop": "➿",

2944 "bangbang": "‼",

2945 "double_vertical_bar": "⏸",

2946 "dove_of_peace": "🕊",

2947 "small_red_triangle_down": "🔻",

2948 "arrow_down_small": "🔽",

2949 "arrow_down": "⬇",

2950 "dromedary_camel": "🐪",

2951 "e__mail": "📧",

2952 "corn": "🌽",

2953 "ear_of_rice": "🌾",

2954 "earth_americas": "🌎",

2955 "earth_asia": "🌏",

2956 "earth_africa": "🌍",

2957 "eight_pointed_black_star": "✴",

2958 "eight_spoked_asterisk": "✳",

2959 "eject_symbol": "⏏",

2960 "bulb": "💡",

2961 "emoji_modifier_fitzpatrick_type__1__2": "🏻",

2962 "emoji_modifier_fitzpatrick_type__3": "🏼",

2963 "emoji_modifier_fitzpatrick_type__4": "🏽",

2964 "emoji_modifier_fitzpatrick_type__5": "🏾",

2965 "emoji_modifier_fitzpatrick_type__6": "🏿",

2966 "end": "🔚",

2967 "email": "✉",

2968 "european_castle": "🏰",

2969 "european_post_office": "🏤",

2970 "interrobang": "⁉",

2971 "expressionless": "😑",

2972 "eyeglasses": "👓",

2973 "massage": "💆",

2974 "yum": "😋",

2975 "scream": "😱",

2976 "kissing_heart": "😘",

2977 "sweat": "😓",

2978 "face_with_head__bandage": "🤕",

2979 "triumph": "😤",

2980 "mask": "😷",

2981 "no_good": "🙅",

2982 "ok_woman": "🙆",

2983 "open_mouth": "😮",

2984 "cold_sweat": "😰",

2985 "stuck_out_tongue": "😛",

2986 "stuck_out_tongue_closed_eyes": "😝",

2987 "stuck_out_tongue_winking_eye": "😜",

2988 "joy": "😂",

2989 "no_mouth": "😶",

2990 "santa": "🎅",

2991 "fax": "📠",

2992 "fearful": "😨",

2993 "field_hockey_stick_and_ball": "🏑",

2994 "first_quarter_moon_with_face": "🌛",

2995 "fish_cake": "🍥",

2996 "fishing_pole_and_fish": "🎣",

2997 "facepunch": "👊",

2998 "punch": "👊",

2999 "flag_for_afghanistan": "🇦🇫",

3000 "flag_for_albania": "🇦🇱",

3001 "flag_for_algeria": "🇩🇿",

3002 "flag_for_american_samoa": "🇦🇸",

3003 "flag_for_andorra": "🇦🇩",

3004 "flag_for_angola": "🇦🇴",

3005 "flag_for_anguilla": "🇦🇮",

3006 "flag_for_antarctica": "🇦🇶",

3007 "flag_for_antigua_&_barbuda": "🇦🇬",

3008 "flag_for_argentina": "🇦🇷",

3009 "flag_for_armenia": "🇦🇲",

3010 "flag_for_aruba": "🇦🇼",

3011 "flag_for_ascension_island": "🇦🇨",

3012 "flag_for_australia": "🇦🇺",

3013 "flag_for_austria": "🇦🇹",

3014 "flag_for_azerbaijan": "🇦🇿",

3015 "flag_for_bahamas": "🇧🇸",

3016 "flag_for_bahrain": "🇧🇭",

3017 "flag_for_bangladesh": "🇧🇩",

3018 "flag_for_barbados": "🇧🇧",

3019 "flag_for_belarus": "🇧🇾",

3020 "flag_for_belgium": "🇧🇪",

3021 "flag_for_belize": "🇧🇿",

3022 "flag_for_benin": "🇧🇯",

3023 "flag_for_bermuda": "🇧🇲",

3024 "flag_for_bhutan": "🇧🇹",

3025 "flag_for_bolivia": "🇧🇴",

3026 "flag_for_bosnia_&_herzegovina": "🇧🇦",

3027 "flag_for_botswana": "🇧🇼",

3028 "flag_for_bouvet_island": "🇧🇻",

3029 "flag_for_brazil": "🇧🇷",

3030 "flag_for_british_indian_ocean_territory": "🇮🇴",

3031 "flag_for_british_virgin_islands": "🇻🇬",

3032 "flag_for_brunei": "🇧🇳",

3033 "flag_for_bulgaria": "🇧🇬",

3034 "flag_for_burkina_faso": "🇧🇫",

3035 "flag_for_burundi": "🇧🇮",

3036 "flag_for_cambodia": "🇰🇭",

3037 "flag_for_cameroon": "🇨🇲",

3038 "flag_for_canada": "🇨🇦",

3039 "flag_for_canary_islands": "🇮🇨",

3040 "flag_for_cape_verde": "🇨🇻",

3041 "flag_for_caribbean_netherlands": "🇧🇶",

3042 "flag_for_cayman_islands": "🇰🇾",

3043 "flag_for_central_african_republic": "🇨🇫",

3044 "flag_for_ceuta_&_melilla": "🇪🇦",

3045 "flag_for_chad": "🇹🇩",

3046 "flag_for_chile": "🇨🇱",

3047 "flag_for_china": "🇨🇳",

3048 "flag_for_christmas_island": "🇨🇽",

3049 "flag_for_clipperton_island": "🇨🇵",

3050 "flag_for_cocos__islands": "🇨🇨",

3051 "flag_for_colombia": "🇨🇴",

3052 "flag_for_comoros": "🇰🇲",

3053 "flag_for_congo____brazzaville": "🇨🇬",

3054 "flag_for_congo____kinshasa": "🇨🇩",

3055 "flag_for_cook_islands": "🇨🇰",

3056 "flag_for_costa_rica": "🇨🇷",

3057 "flag_for_croatia": "🇭🇷",

3058 "flag_for_cuba": "🇨🇺",

3059 "flag_for_curaçao": "🇨🇼",

3060 "flag_for_cyprus": "🇨🇾",

3061 "flag_for_czech_republic": "🇨🇿",

3062 "flag_for_côte_d’ivoire": "🇨🇮",

3063 "flag_for_denmark": "🇩🇰",

3064 "flag_for_diego_garcia": "🇩🇬",

3065 "flag_for_djibouti": "🇩🇯",

3066 "flag_for_dominica": "🇩🇲",

3067 "flag_for_dominican_republic": "🇩🇴",

3068 "flag_for_ecuador": "🇪🇨",

3069 "flag_for_egypt": "🇪🇬",

3070 "flag_for_el_salvador": "🇸🇻",

3071 "flag_for_equatorial_guinea": "🇬🇶",

3072 "flag_for_eritrea": "🇪🇷",

3073 "flag_for_estonia": "🇪🇪",

3074 "flag_for_ethiopia": "🇪🇹",

3075 "flag_for_european_union": "🇪🇺",

3076 "flag_for_falkland_islands": "🇫🇰",

3077 "flag_for_faroe_islands": "🇫🇴",

3078 "flag_for_fiji": "🇫🇯",

3079 "flag_for_finland": "🇫🇮",

3080 "flag_for_france": "🇫🇷",

3081 "flag_for_french_guiana": "🇬🇫",

3082 "flag_for_french_polynesia": "🇵🇫",

3083 "flag_for_french_southern_territories": "🇹🇫",

3084 "flag_for_gabon": "🇬🇦",

3085 "flag_for_gambia": "🇬🇲",

3086 "flag_for_georgia": "🇬🇪",

3087 "flag_for_germany": "🇩🇪",

3088 "flag_for_ghana": "🇬🇭",

3089 "flag_for_gibraltar": "🇬🇮",

3090 "flag_for_greece": "🇬🇷",

3091 "flag_for_greenland": "🇬🇱",

3092 "flag_for_grenada": "🇬🇩",

3093 "flag_for_guadeloupe": "🇬🇵",

3094 "flag_for_guam": "🇬🇺",

3095 "flag_for_guatemala": "🇬🇹",

3096 "flag_for_guernsey": "🇬🇬",

3097 "flag_for_guinea": "🇬🇳",

3098 "flag_for_guinea__bissau": "🇬🇼",

3099 "flag_for_guyana": "🇬🇾",

3100 "flag_for_haiti": "🇭🇹",

3101 "flag_for_heard_&_mcdonald_islands": "🇭🇲",

3102 "flag_for_honduras": "🇭🇳",

3103 "flag_for_hong_kong": "🇭🇰",

3104 "flag_for_hungary": "🇭🇺",

3105 "flag_for_iceland": "🇮🇸",

3106 "flag_for_india": "🇮🇳",

3107 "flag_for_indonesia": "🇮🇩",

3108 "flag_for_iran": "🇮🇷",

3109 "flag_for_iraq": "🇮🇶",

3110 "flag_for_ireland": "🇮🇪",

3111 "flag_for_isle_of_man": "🇮🇲",

3112 "flag_for_israel": "🇮🇱",

3113 "flag_for_italy": "🇮🇹",

3114 "flag_for_jamaica": "🇯🇲",

3115 "flag_for_japan": "🇯🇵",

3116 "flag_for_jersey": "🇯🇪",

3117 "flag_for_jordan": "🇯🇴",

3118 "flag_for_kazakhstan": "🇰🇿",

3119 "flag_for_kenya": "🇰🇪",

3120 "flag_for_kiribati": "🇰🇮",

3121 "flag_for_kosovo": "🇽🇰",

3122 "flag_for_kuwait": "🇰🇼",

3123 "flag_for_kyrgyzstan": "🇰🇬",

3124 "flag_for_laos": "🇱🇦",

3125 "flag_for_latvia": "🇱🇻",

3126 "flag_for_lebanon": "🇱🇧",

3127 "flag_for_lesotho": "🇱🇸",

3128 "flag_for_liberia": "🇱🇷",

3129 "flag_for_libya": "🇱🇾",

3130 "flag_for_liechtenstein": "🇱🇮",

3131 "flag_for_lithuania": "🇱🇹",

3132 "flag_for_luxembourg": "🇱🇺",

3133 "flag_for_macau": "🇲🇴",

3134 "flag_for_macedonia": "🇲🇰",

3135 "flag_for_madagascar": "🇲🇬",

3136 "flag_for_malawi": "🇲🇼",

3137 "flag_for_malaysia": "🇲🇾",

3138 "flag_for_maldives": "🇲🇻",

3139 "flag_for_mali": "🇲🇱",

3140 "flag_for_malta": "🇲🇹",

3141 "flag_for_marshall_islands": "🇲🇭",

3142 "flag_for_martinique": "🇲🇶",

3143 "flag_for_mauritania": "🇲🇷",

3144 "flag_for_mauritius": "🇲🇺",

3145 "flag_for_mayotte": "🇾🇹",

3146 "flag_for_mexico": "🇲🇽",

3147 "flag_for_micronesia": "🇫🇲",

3148 "flag_for_moldova": "🇲🇩",

3149 "flag_for_monaco": "🇲🇨",

3150 "flag_for_mongolia": "🇲🇳",

3151 "flag_for_montenegro": "🇲🇪",

3152 "flag_for_montserrat": "🇲🇸",

3153 "flag_for_morocco": "🇲🇦",

3154 "flag_for_mozambique": "🇲🇿",

3155 "flag_for_myanmar": "🇲🇲",

3156 "flag_for_namibia": "🇳🇦",

3157 "flag_for_nauru": "🇳🇷",

3158 "flag_for_nepal": "🇳🇵",

3159 "flag_for_netherlands": "🇳🇱",

3160 "flag_for_new_caledonia": "🇳🇨",

3161 "flag_for_new_zealand": "🇳🇿",

3162 "flag_for_nicaragua": "🇳🇮",

3163 "flag_for_niger": "🇳🇪",

3164 "flag_for_nigeria": "🇳🇬",

3165 "flag_for_niue": "🇳🇺",

3166 "flag_for_norfolk_island": "🇳🇫",

3167 "flag_for_north_korea": "🇰🇵",

3168 "flag_for_northern_mariana_islands": "🇲🇵",

3169 "flag_for_norway": "🇳🇴",

3170 "flag_for_oman": "🇴🇲",

3171 "flag_for_pakistan": "🇵🇰",

3172 "flag_for_palau": "🇵🇼",

3173 "flag_for_palestinian_territories": "🇵🇸",

3174 "flag_for_panama": "🇵🇦",

3175 "flag_for_papua_new_guinea": "🇵🇬",

3176 "flag_for_paraguay": "🇵🇾",

3177 "flag_for_peru": "🇵🇪",

3178 "flag_for_philippines": "🇵🇭",

3179 "flag_for_pitcairn_islands": "🇵🇳",

3180 "flag_for_poland": "🇵🇱",

3181 "flag_for_portugal": "🇵🇹",

3182 "flag_for_puerto_rico": "🇵🇷",

3183 "flag_for_qatar": "🇶🇦",

3184 "flag_for_romania": "🇷🇴",

3185 "flag_for_russia": "🇷🇺",

3186 "flag_for_rwanda": "🇷🇼",

3187 "flag_for_réunion": "🇷🇪",

3188 "flag_for_samoa": "🇼🇸",

3189 "flag_for_san_marino": "🇸🇲",

3190 "flag_for_saudi_arabia": "🇸🇦",

3191 "flag_for_senegal": "🇸🇳",

3192 "flag_for_serbia": "🇷🇸",

3193 "flag_for_seychelles": "🇸🇨",

3194 "flag_for_sierra_leone": "🇸🇱",

3195 "flag_for_singapore": "🇸🇬",

3196 "flag_for_sint_maarten": "🇸🇽",

3197 "flag_for_slovakia": "🇸🇰",

3198 "flag_for_slovenia": "🇸🇮",

3199 "flag_for_solomon_islands": "🇸🇧",

3200 "flag_for_somalia": "🇸🇴",

3201 "flag_for_south_africa": "🇿🇦",

3202 "flag_for_south_georgia_&_south_sandwich_islands": "🇬🇸",

3203 "flag_for_south_korea": "🇰🇷",

3204 "flag_for_south_sudan": "🇸🇸",

3205 "flag_for_spain": "🇪🇸",

3206 "flag_for_sri_lanka": "🇱🇰",

3207 "flag_for_st._barthélemy": "🇧🇱",

3208 "flag_for_st._helena": "🇸🇭",

3209 "flag_for_st._kitts_&_nevis": "🇰🇳",

3210 "flag_for_st._lucia": "🇱🇨",

3211 "flag_for_st._martin": "🇲🇫",

3212 "flag_for_st._pierre_&_miquelon": "🇵🇲",

3213 "flag_for_st._vincent_&_grenadines": "🇻🇨",

3214 "flag_for_sudan": "🇸🇩",

3215 "flag_for_suriname": "🇸🇷",

3216 "flag_for_svalbard_&_jan_mayen": "🇸🇯",

3217 "flag_for_swaziland": "🇸🇿",

3218 "flag_for_sweden": "🇸🇪",

3219 "flag_for_switzerland": "🇨🇭",

3220 "flag_for_syria": "🇸🇾",

3221 "flag_for_são_tomé_&_príncipe": "🇸🇹",

3222 "flag_for_taiwan": "🇹🇼",

3223 "flag_for_tajikistan": "🇹🇯",

3224 "flag_for_tanzania": "🇹🇿",

3225 "flag_for_thailand": "🇹🇭",

3226 "flag_for_timor__leste": "🇹🇱",

3227 "flag_for_togo": "🇹🇬",

3228 "flag_for_tokelau": "🇹🇰",

3229 "flag_for_tonga": "🇹🇴",

3230 "flag_for_trinidad_&_tobago": "🇹🇹",

3231 "flag_for_tristan_da_cunha": "🇹🇦",

3232 "flag_for_tunisia": "🇹🇳",

3233 "flag_for_turkey": "🇹🇷",

3234 "flag_for_turkmenistan": "🇹🇲",

3235 "flag_for_turks_&_caicos_islands": "🇹🇨",

3236 "flag_for_tuvalu": "🇹🇻",

3237 "flag_for_u.s._outlying_islands": "🇺🇲",

3238 "flag_for_u.s._virgin_islands": "🇻🇮",

3239 "flag_for_uganda": "🇺🇬",

3240 "flag_for_ukraine": "🇺🇦",

3241 "flag_for_united_arab_emirates": "🇦🇪",

3242 "flag_for_united_kingdom": "🇬🇧",

3243 "flag_for_united_states": "🇺🇸",

3244 "flag_for_uruguay": "🇺🇾",

3245 "flag_for_uzbekistan": "🇺🇿",

3246 "flag_for_vanuatu": "🇻🇺",

3247 "flag_for_vatican_city": "🇻🇦",

3248 "flag_for_venezuela": "🇻🇪",

3249 "flag_for_vietnam": "🇻🇳",

3250 "flag_for_wallis_&_futuna": "🇼🇫",

3251 "flag_for_western_sahara": "🇪🇭",

3252 "flag_for_yemen": "🇾🇪",

3253 "flag_for_zambia": "🇿🇲",

3254 "flag_for_zimbabwe": "🇿🇼",

3255 "flag_for_åland_islands": "🇦🇽",

3256 "golf": "⛳",

3257 "fleur__de__lis": "⚜",

3258 "muscle": "💪",

3259 "flushed": "😳",

3260 "frame_with_picture": "🖼",

3261 "fries": "🍟",

3262 "frog": "🐸",

3263 "hatched_chick": "🐥",

3264 "frowning": "😦",

3265 "fuelpump": "⛽",

3266 "full_moon_with_face": "🌝",

3267 "gem": "💎",

3268 "star2": "🌟",

3269 "golfer": "🏌",

3270 "mortar_board": "🎓",

3271 "grimacing": "😬",

3272 "smile_cat": "😸",

3273 "grinning": "😀",

3274 "grin": "😁",

3275 "heartpulse": "💗",

3276 "guardsman": "💂",

3277 "haircut": "💇",

3278 "hamster": "🐹",

3279 "raising_hand": "🙋",

3280 "headphones": "🎧",

3281 "hear_no_evil": "🙉",

3282 "cupid": "💘",

3283 "gift_heart": "💝",

3284 "heart": "❤",

3285 "exclamation": "❗",

3286 "heavy_exclamation_mark": "❗",

3287 "heavy_heart_exclamation_mark_ornament": "❣",

3288 "o": "⭕",

3289 "helm_symbol": "⎈",

3290 "helmet_with_white_cross": "⛑",

3291 "high_heel": "👠",

3292 "bullettrain_side": "🚄",

3293 "bullettrain_front": "🚅",

3294 "high_brightness": "🔆",

3295 "zap": "⚡",

3296 "hocho": "🔪",

3297 "knife": "🔪",

3298 "bee": "🐝",

3299 "traffic_light": "🚥",

3300 "racehorse": "🐎",

3301 "coffee": "☕",

3302 "hotsprings": "♨",

3303 "hourglass": "⌛",

3304 "hourglass_flowing_sand": "⏳",

3305 "house_buildings": "🏘",

3306 "100": "💯",

3307 "hushed": "😯",

3308 "ice_hockey_stick_and_puck": "🏒",

3309 "imp": "👿",

3310 "information_desk_person": "💁",

3311 "information_source": "ℹ",

3312 "capital_abcd": "🔠",

3313 "abc": "🔤",

3314 "abcd": "🔡",

3315 "1234": "🔢",

3316 "symbols": "🔣",

3317 "izakaya_lantern": "🏮",

3318 "lantern": "🏮",

3319 "jack_o_lantern": "🎃",

3320 "dolls": "🎎",

3321 "japanese_goblin": "👺",

3322 "japanese_ogre": "👹",

3323 "beginner": "🔰",

3324 "zero": "0️⃣",

3325 "one": "1️⃣",

3326 "ten": "🔟",

3327 "two": "2️⃣",

3328 "three": "3️⃣",

3329 "four": "4️⃣",

3330 "five": "5️⃣",

3331 "six": "6️⃣",

3332 "seven": "7️⃣",

3333 "eight": "8️⃣",

3334 "nine": "9️⃣",

3335 "couplekiss": "💏",

3336 "kissing_cat": "😽",

3337 "kissing": "😗",

3338 "kissing_closed_eyes": "😚",

3339 "kissing_smiling_eyes": "😙",

3340 "beetle": "🐞",

3341 "large_blue_circle": "🔵",

3342 "last_quarter_moon_with_face": "🌜",

3343 "leaves": "🍃",

3344 "mag": "🔍",

3345 "left_right_arrow": "↔",

3346 "leftwards_arrow_with_hook": "↩",

3347 "arrow_left": "⬅",

3348 "lock": "🔒",

3349 "lock_with_ink_pen": "🔏",

3350 "sob": "😭",

3351 "low_brightness": "🔅",

3352 "lower_left_ballpoint_pen": "🖊",

3353 "lower_left_crayon": "🖍",

3354 "lower_left_fountain_pen": "🖋",

3355 "lower_left_paintbrush": "🖌",

3356 "mahjong": "🀄",

3357 "couple": "👫",

3358 "man_in_business_suit_levitating": "🕴",

3359 "man_with_gua_pi_mao": "👲",

3360 "man_with_turban": "👳",

3361 "mans_shoe": "👞",

3362 "shoe": "👞",

3363 "menorah_with_nine_branches": "🕎",

3364 "mens": "🚹",

3365 "minidisc": "💽",

3366 "iphone": "📱",

3367 "calling": "📲",

3368 "money__mouth_face": "🤑",

3369 "moneybag": "💰",

3370 "rice_scene": "🎑",

3371 "mountain_bicyclist": "🚵",

3372 "mouse2": "🐁",

3373 "lips": "👄",

3374 "moyai": "🗿",

3375 "notes": "🎶",

3376 "nail_care": "💅",

3377 "ab": "🆎",

3378 "negative_squared_cross_mark": "❎",

3379 "a": "🅰",

3380 "b": "🅱",

3381 "o2": "🅾",

3382 "parking": "🅿",

3383 "new_moon_with_face": "🌚",

3384 "no_entry_sign": "🚫",

3385 "underage": "🔞",

3386 "non__potable_water": "🚱",

3387 "arrow_upper_right": "↗",

3388 "arrow_upper_left": "↖",

3389 "office": "🏢",

3390 "older_man": "👴",

3391 "older_woman": "👵",

3392 "om_symbol": "🕉",

3393 "on": "🔛",

3394 "book": "📖",

3395 "unlock": "🔓",

3396 "mailbox_with_no_mail": "📭",

3397 "mailbox_with_mail": "📬",

3398 "cd": "💿",

3399 "tada": "🎉",

3400 "feet": "🐾",

3401 "walking": "🚶",

3402 "pencil2": "✏",

3403 "pensive": "😔",

3404 "persevere": "😣",

3405 "bow": "🙇",

3406 "raised_hands": "🙌",

3407 "person_with_ball": "⛹",

3408 "person_with_blond_hair": "👱",

3409 "pray": "🙏",

3410 "person_with_pouting_face": "🙎",

3411 "computer": "💻",

3412 "pig2": "🐖",

3413 "hankey": "💩",

3414 "poop": "💩",

3415 "shit": "💩",

3416 "bamboo": "🎍",

3417 "gun": "🔫",

3418 "black_joker": "🃏",

3419 "rotating_light": "🚨",

3420 "cop": "👮",

3421 "stew": "🍲",

3422 "pouch": "👝",

3423 "pouting_cat": "😾",

3424 "rage": "😡",

3425 "put_litter_in_its_place": "🚮",

3426 "rabbit2": "🐇",

3427 "racing_motorcycle": "🏍",

3428 "radioactive_sign": "☢",

3429 "fist": "✊",

3430 "hand": "✋",

3431 "raised_hand_with_fingers_splayed": "🖐",

3432 "raised_hand_with_part_between_middle_and_ring_fingers": "🖖",

3433 "blue_car": "🚙",

3434 "apple": "🍎",

3435 "relieved": "😌",

3436 "reversed_hand_with_middle_finger_extended": "🖕",

3437 "mag_right": "🔎",

3438 "arrow_right_hook": "↪",

3439 "sweet_potato": "🍠",

3440 "robot": "🤖",

3441 "rolled__up_newspaper": "🗞",

3442 "rowboat": "🚣",

3443 "runner": "🏃",

3444 "running": "🏃",

3445 "running_shirt_with_sash": "🎽",

3446 "boat": "⛵",

3447 "scales": "⚖",

3448 "school_satchel": "🎒",

3449 "scorpius": "♏",

3450 "see_no_evil": "🙈",

3451 "sheep": "🐑",

3452 "stars": "🌠",

3453 "cake": "🍰",

3454 "six_pointed_star": "🔯",

3455 "ski": "🎿",

3456 "sleeping_accommodation": "🛌",

3457 "sleeping": "😴",

3458 "sleepy": "😪",

3459 "sleuth_or_spy": "🕵",

3460 "heart_eyes_cat": "😻",

3461 "smiley_cat": "😺",

3462 "innocent": "😇",

3463 "heart_eyes": "😍",

3464 "smiling_imp": "😈",

3465 "smiley": "😃",

3466 "sweat_smile": "😅",

3467 "smile": "😄",

3468 "laughing": "😆",

3469 "satisfied": "😆",

3470 "blush": "😊",

3471 "smirk": "😏",

3472 "smoking": "🚬",

3473 "snow_capped_mountain": "🏔",

3474 "soccer": "⚽",

3475 "icecream": "🍦",

3476 "soon": "🔜",

3477 "arrow_lower_right": "↘",

3478 "arrow_lower_left": "↙",

3479 "speak_no_evil": "🙊",

3480 "speaker": "🔈",

3481 "mute": "🔇",

3482 "sound": "🔉",

3483 "loud_sound": "🔊",

3484 "speaking_head_in_silhouette": "🗣",

3485 "spiral_calendar_pad": "🗓",

3486 "spiral_note_pad": "🗒",

3487 "shell": "🐚",

3488 "sweat_drops": "💦",

3489 "u5272": "🈹",

3490 "u5408": "🈴",

3491 "u55b6": "🈺",

3492 "u6307": "🈯",

3493 "u6708": "🈷",

3494 "u6709": "🈶",

3495 "u6e80": "🈵",

3496 "u7121": "🈚",

3497 "u7533": "🈸",

3498 "u7981": "🈲",

3499 "u7a7a": "🈳",

3500 "cl": "🆑",

3501 "cool": "🆒",

3502 "free": "🆓",

3503 "id": "🆔",

3504 "koko": "🈁",

3505 "sa": "🈂",

3506 "new": "🆕",

3507 "ng": "🆖",

3508 "ok": "🆗",

3509 "sos": "🆘",

3510 "up": "🆙",

3511 "vs": "🆚",

3512 "steam_locomotive": "🚂",

3513 "ramen": "🍜",

3514 "partly_sunny": "⛅",

3515 "city_sunrise": "🌇",

3516 "surfer": "🏄",

3517 "swimmer": "🏊",

3518 "shirt": "👕",

3519 "tshirt": "👕",

3520 "table_tennis_paddle_and_ball": "🏓",

3521 "tea": "🍵",

3522 "tv": "📺",

3523 "three_button_mouse": "🖱",

3524 "+1": "👍",

3525 "thumbsup": "👍",

3526 "__1": "👎",

3527 "-1": "👎",

3528 "thumbsdown": "👎",

3529 "thunder_cloud_and_rain": "⛈",

3530 "tiger2": "🐅",

3531 "tophat": "🎩",

3532 "top": "🔝",

3533 "tm": "™",

3534 "train2": "🚆",

3535 "triangular_flag_on_post": "🚩",

3536 "trident": "🔱",

3537 "twisted_rightwards_arrows": "🔀",

3538 "unamused": "😒",

3539 "small_red_triangle": "🔺",

3540 "arrow_up_small": "🔼",

3541 "arrow_up_down": "↕",

3542 "upside__down_face": "🙃",

3543 "arrow_up": "⬆",

3544 "v": "✌",

3545 "vhs": "📼",

3546 "wc": "🚾",

3547 "ocean": "🌊",

3548 "waving_black_flag": "🏴",

3549 "wave": "👋",

3550 "waving_white_flag": "🏳",

3551 "moon": "🌔",

3552 "scream_cat": "🙀",

3553 "weary": "😩",

3554 "weight_lifter": "🏋",

3555 "whale2": "🐋",

3556 "wheelchair": "♿",

3557 "point_down": "👇",

3558 "grey_exclamation": "❕",

3559 "white_frowning_face": "☹",

3560 "white_check_mark": "✅",

3561 "point_left": "👈",

3562 "white_medium_small_square": "◽",

3563 "star": "⭐",

3564 "grey_question": "❔",

3565 "point_right": "👉",

3566 "relaxed": "☺",

3567 "white_sun_behind_cloud": "🌥",

3568 "white_sun_behind_cloud_with_rain": "🌦",

3569 "white_sun_with_small_cloud": "🌤",

3570 "point_up_2": "👆",

3571 "point_up": "☝",

3572 "wind_blowing_face": "🌬",

3573 "wink": "😉",

3574 "wolf": "🐺",

3575 "dancers": "👯",

3576 "boot": "👢",

3577 "womans_clothes": "👚",

3578 "womans_hat": "👒",

3579 "sandal": "👡",

3580 "womens": "🚺",

3581 "worried": "😟",

3582 "gift": "🎁",

3583 "zipper__mouth_face": "🤐",

3584 "regional_indicator_a": "🇦",

3585 "regional_indicator_b": "🇧",

3586 "regional_indicator_c": "🇨",

3587 "regional_indicator_d": "🇩",

3588 "regional_indicator_e": "🇪",

3589 "regional_indicator_f": "🇫",

3590 "regional_indicator_g": "🇬",

3591 "regional_indicator_h": "🇭",

3592 "regional_indicator_i": "🇮",

3593 "regional_indicator_j": "🇯",

3594 "regional_indicator_k": "🇰",

3595 "regional_indicator_l": "🇱",

3596 "regional_indicator_m": "🇲",

3597 "regional_indicator_n": "🇳",

3598 "regional_indicator_o": "🇴",

3599 "regional_indicator_p": "🇵",

3600 "regional_indicator_q": "🇶",

3601 "regional_indicator_r": "🇷",

3602 "regional_indicator_s": "🇸",

3603 "regional_indicator_t": "🇹",

3604 "regional_indicator_u": "🇺",

3605 "regional_indicator_v": "🇻",

3606 "regional_indicator_w": "🇼",

3607 "regional_indicator_x": "🇽",

3608 "regional_indicator_y": "🇾",

3609 "regional_indicator_z": "🇿",

3610}